@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class AccountBalance extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AVAILABLE |
static String |
SERIALIZED_NAME_CURRENT |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_LAST_UPDATED_DATETIME |
static String |
SERIALIZED_NAME_LIMIT |
static String |
SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE |
| Constructor and Description |
|---|
AccountBalance() |
| Modifier and Type | Method and Description |
|---|---|
AccountBalance |
available(Double available) |
AccountBalance |
current(Double current) |
boolean |
equals(Object o) |
Double |
getAvailable()
The amount of funds available to be withdrawn from the account, as determined by the financial institution.
|
Double |
getCurrent()
The total amount of funds in or owed by the account.
|
String |
getIsoCurrencyCode()
The ISO-4217 currency code of the balance.
|
OffsetDateTime |
getLastUpdatedDatetime()
Timestamp in [ISO 8601](https://wikipedia.org/wiki/ISO_8601) format (`YYYY-MM-DDTHH:mm:ssZ`) indicating the last time that the balance for the given account has been updated This is currently only provided when the `min_last_updated_datetime` is passed when calling `/accounts/balance/get` for `ins_128026` (Capital One).
|
Double |
getLimit()
For `credit`-type accounts, this represents the credit limit.
|
String |
getUnofficialCurrencyCode()
The unofficial currency code associated with the balance.
|
int |
hashCode() |
AccountBalance |
isoCurrencyCode(String isoCurrencyCode) |
AccountBalance |
lastUpdatedDatetime(OffsetDateTime lastUpdatedDatetime) |
AccountBalance |
limit(Double limit) |
void |
setAvailable(Double available) |
void |
setCurrent(Double current) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setLastUpdatedDatetime(OffsetDateTime lastUpdatedDatetime) |
void |
setLimit(Double limit) |
void |
setUnofficialCurrencyCode(String unofficialCurrencyCode) |
String |
toString() |
AccountBalance |
unofficialCurrencyCode(String unofficialCurrencyCode) |
public static final String SERIALIZED_NAME_AVAILABLE
public static final String SERIALIZED_NAME_CURRENT
public static final String SERIALIZED_NAME_LIMIT
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE
public static final String SERIALIZED_NAME_LAST_UPDATED_DATETIME
public AccountBalance available(Double available)
@Nullable public Double getAvailable()
public void setAvailable(Double available)
public AccountBalance current(Double current)
@Nullable public Double getCurrent()
public void setCurrent(Double current)
public AccountBalance limit(Double limit)
@Nullable public Double getLimit()
public void setLimit(Double limit)
public AccountBalance isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public AccountBalance unofficialCurrencyCode(String unofficialCurrencyCode)
@Nullable public String getUnofficialCurrencyCode()
public void setUnofficialCurrencyCode(String unofficialCurrencyCode)
public AccountBalance lastUpdatedDatetime(OffsetDateTime lastUpdatedDatetime)
@Nullable public OffsetDateTime getLastUpdatedDatetime()
public void setLastUpdatedDatetime(OffsetDateTime lastUpdatedDatetime)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.