public enum AccountSelectionCardinality extends Enum<AccountSelectionCardinality>
| Modifier and Type | Class and Description |
|---|---|
static class |
AccountSelectionCardinality.Adapter |
| Enum Constant and Description |
|---|
ALL |
ENUM_UNKNOWN |
MULTI_SELECT |
SINGLE_SELECT |
| Modifier and Type | Method and Description |
|---|---|
static AccountSelectionCardinality |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static AccountSelectionCardinality |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static AccountSelectionCardinality[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final AccountSelectionCardinality SINGLE_SELECT
public static final AccountSelectionCardinality MULTI_SELECT
public static final AccountSelectionCardinality ALL
public static final AccountSelectionCardinality ENUM_UNKNOWN
public static AccountSelectionCardinality[] values()
for (AccountSelectionCardinality c : AccountSelectionCardinality.values()) System.out.println(c);
public static AccountSelectionCardinality valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<AccountSelectionCardinality>public static AccountSelectionCardinality fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.