public enum ActionState extends Enum<ActionState>
| Modifier and Type | Class and Description |
|---|---|
static class |
ActionState.Adapter |
| Enum Constant and Description |
|---|
ATTEMPT |
ENUM_UNKNOWN |
FAILURE |
SKIPPED |
SUCCESS |
UNKNOWN |
| Modifier and Type | Method and Description |
|---|---|
static ActionState |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static ActionState |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static ActionState[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ActionState UNKNOWN
public static final ActionState ATTEMPT
public static final ActionState SUCCESS
public static final ActionState FAILURE
public static final ActionState SKIPPED
public static final ActionState ENUM_UNKNOWN
public static ActionState[] values()
for (ActionState c : ActionState.values()) System.out.println(c);
public static ActionState valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<ActionState>public static ActionState fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.