public enum AssetReportAddOns extends Enum<AssetReportAddOns>
| Modifier and Type | Class and Description |
|---|---|
static class |
AssetReportAddOns.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
FAST_ASSETS |
INVESTMENTS |
| Modifier and Type | Method and Description |
|---|---|
static AssetReportAddOns |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static AssetReportAddOns |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static AssetReportAddOns[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final AssetReportAddOns INVESTMENTS
public static final AssetReportAddOns FAST_ASSETS
public static final AssetReportAddOns ENUM_UNKNOWN
public static AssetReportAddOns[] values()
for (AssetReportAddOns c : AssetReportAddOns.values()) System.out.println(c);
public static AssetReportAddOns valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<AssetReportAddOns>public static AssetReportAddOns fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.