@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class AssetReportAuditCopyCreateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ASSET_REPORT_TOKEN |
static String |
SERIALIZED_NAME_AUDITOR_ID |
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_SECRET |
| Constructor and Description |
|---|
AssetReportAuditCopyCreateRequest() |
| Modifier and Type | Method and Description |
|---|---|
AssetReportAuditCopyCreateRequest |
assetReportToken(String assetReportToken) |
AssetReportAuditCopyCreateRequest |
auditorId(String auditorId) |
AssetReportAuditCopyCreateRequest |
clientId(String clientId) |
boolean |
equals(Object o) |
String |
getAssetReportToken()
A token that can be provided to endpoints such as `/asset_report/get` or `/asset_report/pdf/get` to fetch or update an Asset Report.
|
String |
getAuditorId()
The `auditor_id` of the third party with whom you would like to share the Asset Report.
|
String |
getClientId()
Your Plaid API `client_id`.
|
String |
getSecret()
Your Plaid API `secret`.
|
int |
hashCode() |
AssetReportAuditCopyCreateRequest |
secret(String secret) |
void |
setAssetReportToken(String assetReportToken) |
void |
setAuditorId(String auditorId) |
void |
setClientId(String clientId) |
void |
setSecret(String secret) |
String |
toString() |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_ASSET_REPORT_TOKEN
public static final String SERIALIZED_NAME_AUDITOR_ID
public AssetReportAuditCopyCreateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public AssetReportAuditCopyCreateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public AssetReportAuditCopyCreateRequest assetReportToken(String assetReportToken)
public String getAssetReportToken()
public void setAssetReportToken(String assetReportToken)
public AssetReportAuditCopyCreateRequest auditorId(String auditorId)
@Nullable public String getAuditorId()
public void setAuditorId(String auditorId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.