@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class AssetReportAuditCopyCreateResponse extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AUDIT_COPY_TOKEN |
static String |
SERIALIZED_NAME_REQUEST_ID |
| Constructor and Description |
|---|
AssetReportAuditCopyCreateResponse() |
| Modifier and Type | Method and Description |
|---|---|
AssetReportAuditCopyCreateResponse |
auditCopyToken(String auditCopyToken) |
boolean |
equals(Object o) |
String |
getAuditCopyToken()
A token that can be shared with a third party auditor to allow them to obtain access to the Asset Report.
|
String |
getRequestId()
A unique identifier for the request, which can be used for troubleshooting.
|
int |
hashCode() |
AssetReportAuditCopyCreateResponse |
requestId(String requestId) |
void |
setAuditCopyToken(String auditCopyToken) |
void |
setRequestId(String requestId) |
String |
toString() |
public static final String SERIALIZED_NAME_AUDIT_COPY_TOKEN
public static final String SERIALIZED_NAME_REQUEST_ID
public AssetReportAuditCopyCreateResponse auditCopyToken(String auditCopyToken)
public String getAuditCopyToken()
public void setAuditCopyToken(String auditCopyToken)
public AssetReportAuditCopyCreateResponse requestId(String requestId)
public String getRequestId()
public void setRequestId(String requestId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.