@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class AssetReportInvestments extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCOUNT_ID |
static String |
SERIALIZED_NAME_AMOUNT |
static String |
SERIALIZED_NAME_DATE |
static String |
SERIALIZED_NAME_FEES |
static String |
SERIALIZED_NAME_INVESTMENT_TRANSACTION_ID |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_NAME |
static String |
SERIALIZED_NAME_PRICE |
static String |
SERIALIZED_NAME_QUANTITY |
static String |
SERIALIZED_NAME_SECURITY_ID |
static String |
SERIALIZED_NAME_SUBTYPE |
static String |
SERIALIZED_NAME_TYPE |
static String |
SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE |
| Constructor and Description |
|---|
AssetReportInvestments() |
| Modifier and Type | Method and Description |
|---|---|
AssetReportInvestments |
accountId(String accountId) |
AssetReportInvestments |
amount(Double amount) |
AssetReportInvestments |
date(LocalDate date) |
boolean |
equals(Object o) |
AssetReportInvestments |
fees(Double fees) |
String |
getAccountId()
The `account_id` of the account against which this transaction posted.
|
Double |
getAmount()
The complete value of the transaction.
|
LocalDate |
getDate()
The [ISO 8601](https://wikipedia.org/wiki/ISO_8601) posting date for the transaction.
|
Double |
getFees()
The combined value of all fees applied to this transaction
|
String |
getInvestmentTransactionId()
The ID of the Investment transaction, unique across all Plaid transactions.
|
String |
getIsoCurrencyCode()
The ISO-4217 currency code of the transaction.
|
String |
getName()
The institution’s description of the transaction.
|
Double |
getPrice()
The price of the security at which this transaction occurred.
|
Double |
getQuantity()
The number of units of the security involved in this transaction.
|
String |
getSecurityId()
The `security_id` to which this transaction is related.
|
InvestmentTransactionSubtype |
getSubtype()
Get subtype
|
InvestmentTransactionType |
getType()
Get type
|
String |
getUnofficialCurrencyCode()
The unofficial currency code associated with the holding.
|
int |
hashCode() |
AssetReportInvestments |
investmentTransactionId(String investmentTransactionId) |
AssetReportInvestments |
isoCurrencyCode(String isoCurrencyCode) |
AssetReportInvestments |
name(String name) |
AssetReportInvestments |
price(Double price) |
AssetReportInvestments |
quantity(Double quantity) |
AssetReportInvestments |
securityId(String securityId) |
void |
setAccountId(String accountId) |
void |
setAmount(Double amount) |
void |
setDate(LocalDate date) |
void |
setFees(Double fees) |
void |
setInvestmentTransactionId(String investmentTransactionId) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setName(String name) |
void |
setPrice(Double price) |
void |
setQuantity(Double quantity) |
void |
setSecurityId(String securityId) |
void |
setSubtype(InvestmentTransactionSubtype subtype) |
void |
setType(InvestmentTransactionType type) |
void |
setUnofficialCurrencyCode(String unofficialCurrencyCode) |
AssetReportInvestments |
subtype(InvestmentTransactionSubtype subtype) |
String |
toString() |
AssetReportInvestments |
type(InvestmentTransactionType type) |
AssetReportInvestments |
unofficialCurrencyCode(String unofficialCurrencyCode) |
public static final String SERIALIZED_NAME_INVESTMENT_TRANSACTION_ID
public static final String SERIALIZED_NAME_ACCOUNT_ID
public static final String SERIALIZED_NAME_SECURITY_ID
public static final String SERIALIZED_NAME_DATE
public static final String SERIALIZED_NAME_NAME
public static final String SERIALIZED_NAME_QUANTITY
public static final String SERIALIZED_NAME_AMOUNT
public static final String SERIALIZED_NAME_PRICE
public static final String SERIALIZED_NAME_FEES
public static final String SERIALIZED_NAME_TYPE
public static final String SERIALIZED_NAME_SUBTYPE
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE
public AssetReportInvestments investmentTransactionId(String investmentTransactionId)
public String getInvestmentTransactionId()
public void setInvestmentTransactionId(String investmentTransactionId)
public AssetReportInvestments accountId(String accountId)
public String getAccountId()
public void setAccountId(String accountId)
public AssetReportInvestments securityId(String securityId)
@Nullable public String getSecurityId()
public void setSecurityId(String securityId)
public AssetReportInvestments date(LocalDate date)
public LocalDate getDate()
public void setDate(LocalDate date)
public AssetReportInvestments name(String name)
public String getName()
public void setName(String name)
public AssetReportInvestments quantity(Double quantity)
public Double getQuantity()
public void setQuantity(Double quantity)
public AssetReportInvestments amount(Double amount)
public Double getAmount()
public void setAmount(Double amount)
public AssetReportInvestments price(Double price)
public Double getPrice()
public void setPrice(Double price)
public AssetReportInvestments fees(Double fees)
@Nullable public Double getFees()
public void setFees(Double fees)
public AssetReportInvestments type(InvestmentTransactionType type)
public InvestmentTransactionType getType()
public void setType(InvestmentTransactionType type)
public AssetReportInvestments subtype(InvestmentTransactionSubtype subtype)
public InvestmentTransactionSubtype getSubtype()
public void setSubtype(InvestmentTransactionSubtype subtype)
public AssetReportInvestments isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public AssetReportInvestments unofficialCurrencyCode(String unofficialCurrencyCode)
@Nullable public String getUnofficialCurrencyCode()
public void setUnofficialCurrencyCode(String unofficialCurrencyCode)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.