@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class AssetReportRefreshRequestOptions extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CLIENT_REPORT_ID |
static String |
SERIALIZED_NAME_USER |
static String |
SERIALIZED_NAME_WEBHOOK |
| Constructor and Description |
|---|
AssetReportRefreshRequestOptions() |
| Modifier and Type | Method and Description |
|---|---|
AssetReportRefreshRequestOptions |
clientReportId(String clientReportId) |
boolean |
equals(Object o) |
String |
getClientReportId()
Client-generated identifier, which can be used by lenders to track loan applications.
|
AssetReportUser |
getUser()
Get user
|
String |
getWebhook()
URL to which Plaid will send Assets webhooks, for example when the requested Asset Report is ready.
|
int |
hashCode() |
void |
setClientReportId(String clientReportId) |
void |
setUser(AssetReportUser user) |
void |
setWebhook(String webhook) |
String |
toString() |
AssetReportRefreshRequestOptions |
user(AssetReportUser user) |
AssetReportRefreshRequestOptions |
webhook(String webhook) |
public static final String SERIALIZED_NAME_CLIENT_REPORT_ID
public static final String SERIALIZED_NAME_WEBHOOK
public static final String SERIALIZED_NAME_USER
public AssetReportRefreshRequestOptions clientReportId(String clientReportId)
@Nullable public String getClientReportId()
public void setClientReportId(String clientReportId)
public AssetReportRefreshRequestOptions webhook(String webhook)
@Nullable public String getWebhook()
public void setWebhook(String webhook)
public AssetReportRefreshRequestOptions user(AssetReportUser user)
@Nullable public AssetReportUser getUser()
public void setUser(AssetReportUser user)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.