@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class AssetReportTransaction extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCOUNT_ID |
static String |
SERIALIZED_NAME_ACCOUNT_OWNER |
static String |
SERIALIZED_NAME_AMOUNT |
static String |
SERIALIZED_NAME_CATEGORY |
static String |
SERIALIZED_NAME_CATEGORY_ID |
static String |
SERIALIZED_NAME_CHECK_NUMBER |
static String |
SERIALIZED_NAME_CREDIT_CATEGORY |
static String |
SERIALIZED_NAME_DATE |
static String |
SERIALIZED_NAME_DATE_TRANSACTED |
static String |
SERIALIZED_NAME_INCOME_SOURCE_ID |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_LOCATION |
static String |
SERIALIZED_NAME_MERCHANT_NAME |
static String |
SERIALIZED_NAME_NAME |
static String |
SERIALIZED_NAME_ORIGINAL_DESCRIPTION |
static String |
SERIALIZED_NAME_PAYMENT_META |
static String |
SERIALIZED_NAME_PENDING |
static String |
SERIALIZED_NAME_PENDING_TRANSACTION_ID |
static String |
SERIALIZED_NAME_TRANSACTION_ID |
static String |
SERIALIZED_NAME_TRANSACTION_TYPE |
static String |
SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE |
| Constructor and Description |
|---|
AssetReportTransaction() |
| Modifier and Type | Method and Description |
|---|---|
AssetReportTransaction |
accountId(String accountId) |
AssetReportTransaction |
accountOwner(String accountOwner) |
AssetReportTransaction |
addCategoryItem(String categoryItem) |
AssetReportTransaction |
amount(Double amount) |
AssetReportTransaction |
category(List<String> category) |
AssetReportTransaction |
categoryId(String categoryId) |
AssetReportTransaction |
checkNumber(String checkNumber) |
AssetReportTransaction |
creditCategory(CreditCategory creditCategory) |
AssetReportTransaction |
date(LocalDate date) |
AssetReportTransaction |
dateTransacted(String dateTransacted) |
boolean |
equals(Object o) |
String |
getAccountId()
The ID of the account in which this transaction occurred.
|
String |
getAccountOwner()
The name of the account owner.
|
Double |
getAmount()
The settled value of the transaction, denominated in the transaction's currency, as stated in `iso_currency_code` or `unofficial_currency_code`.
|
List<String> |
getCategory()
A hierarchical array of the categories to which this transaction belongs.
|
String |
getCategoryId()
The ID of the category to which this transaction belongs.
|
String |
getCheckNumber()
The check number of the transaction.
|
CreditCategory |
getCreditCategory()
Get creditCategory
|
LocalDate |
getDate()
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted.
|
String |
getDateTransacted()
The date on which the transaction took place, in IS0 8601 format.
|
String |
getIncomeSourceId()
A unique identifier for an income source.
|
String |
getIsoCurrencyCode()
The ISO-4217 currency code of the transaction.
|
Location |
getLocation()
Get location
|
String |
getMerchantName()
The merchant name, as enriched by Plaid from the `name` field.
|
String |
getName()
The merchant name or transaction description.
|
String |
getOriginalDescription()
The string returned by the financial institution to describe the transaction.
|
PaymentMeta |
getPaymentMeta()
Get paymentMeta
|
Boolean |
getPending()
When `true`, identifies the transaction as pending or unsettled.
|
String |
getPendingTransactionId()
The ID of a posted transaction's associated pending transaction, where applicable.
|
String |
getTransactionId()
The unique ID of the transaction.
|
AssetReportTransactionType |
getTransactionType()
Get transactionType
|
String |
getUnofficialCurrencyCode()
The unofficial currency code associated with the transaction.
|
int |
hashCode() |
AssetReportTransaction |
incomeSourceId(String incomeSourceId) |
AssetReportTransaction |
isoCurrencyCode(String isoCurrencyCode) |
AssetReportTransaction |
location(Location location) |
AssetReportTransaction |
merchantName(String merchantName) |
AssetReportTransaction |
name(String name) |
AssetReportTransaction |
originalDescription(String originalDescription) |
AssetReportTransaction |
paymentMeta(PaymentMeta paymentMeta) |
AssetReportTransaction |
pending(Boolean pending) |
AssetReportTransaction |
pendingTransactionId(String pendingTransactionId) |
void |
setAccountId(String accountId) |
void |
setAccountOwner(String accountOwner) |
void |
setAmount(Double amount) |
void |
setCategory(List<String> category) |
void |
setCategoryId(String categoryId) |
void |
setCheckNumber(String checkNumber) |
void |
setCreditCategory(CreditCategory creditCategory) |
void |
setDate(LocalDate date) |
void |
setDateTransacted(String dateTransacted) |
void |
setIncomeSourceId(String incomeSourceId) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setLocation(Location location) |
void |
setMerchantName(String merchantName) |
void |
setName(String name) |
void |
setOriginalDescription(String originalDescription) |
void |
setPaymentMeta(PaymentMeta paymentMeta) |
void |
setPending(Boolean pending) |
void |
setPendingTransactionId(String pendingTransactionId) |
void |
setTransactionId(String transactionId) |
void |
setTransactionType(AssetReportTransactionType transactionType) |
void |
setUnofficialCurrencyCode(String unofficialCurrencyCode) |
String |
toString() |
AssetReportTransaction |
transactionId(String transactionId) |
AssetReportTransaction |
transactionType(AssetReportTransactionType transactionType) |
AssetReportTransaction |
unofficialCurrencyCode(String unofficialCurrencyCode) |
public static final String SERIALIZED_NAME_ACCOUNT_ID
public static final String SERIALIZED_NAME_AMOUNT
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE
public static final String SERIALIZED_NAME_ORIGINAL_DESCRIPTION
public static final String SERIALIZED_NAME_CATEGORY
public static final String SERIALIZED_NAME_CATEGORY_ID
public static final String SERIALIZED_NAME_CREDIT_CATEGORY
public static final String SERIALIZED_NAME_CHECK_NUMBER
public static final String SERIALIZED_NAME_DATE
public static final String SERIALIZED_NAME_DATE_TRANSACTED
public static final String SERIALIZED_NAME_LOCATION
public static final String SERIALIZED_NAME_NAME
public static final String SERIALIZED_NAME_MERCHANT_NAME
public static final String SERIALIZED_NAME_PAYMENT_META
public static final String SERIALIZED_NAME_PENDING
public static final String SERIALIZED_NAME_PENDING_TRANSACTION_ID
public static final String SERIALIZED_NAME_ACCOUNT_OWNER
public static final String SERIALIZED_NAME_TRANSACTION_ID
public static final String SERIALIZED_NAME_TRANSACTION_TYPE
public static final String SERIALIZED_NAME_INCOME_SOURCE_ID
public AssetReportTransaction accountId(String accountId)
public String getAccountId()
public void setAccountId(String accountId)
public AssetReportTransaction amount(Double amount)
public Double getAmount()
public void setAmount(Double amount)
public AssetReportTransaction isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public AssetReportTransaction unofficialCurrencyCode(String unofficialCurrencyCode)
@Nullable public String getUnofficialCurrencyCode()
public void setUnofficialCurrencyCode(String unofficialCurrencyCode)
public AssetReportTransaction originalDescription(String originalDescription)
@Nullable public String getOriginalDescription()
public void setOriginalDescription(String originalDescription)
public AssetReportTransaction category(List<String> category)
public AssetReportTransaction addCategoryItem(String categoryItem)
@Nullable public List<String> getCategory()
public AssetReportTransaction categoryId(String categoryId)
@Nullable public String getCategoryId()
public void setCategoryId(String categoryId)
public AssetReportTransaction creditCategory(CreditCategory creditCategory)
@Nullable public CreditCategory getCreditCategory()
public void setCreditCategory(CreditCategory creditCategory)
public AssetReportTransaction checkNumber(String checkNumber)
@Nullable public String getCheckNumber()
public void setCheckNumber(String checkNumber)
public AssetReportTransaction date(LocalDate date)
public LocalDate getDate()
public void setDate(LocalDate date)
public AssetReportTransaction dateTransacted(String dateTransacted)
@Nullable public String getDateTransacted()
public void setDateTransacted(String dateTransacted)
public AssetReportTransaction location(Location location)
public void setLocation(Location location)
public AssetReportTransaction name(String name)
@Nullable public String getName()
public void setName(String name)
public AssetReportTransaction merchantName(String merchantName)
@Nullable public String getMerchantName()
public void setMerchantName(String merchantName)
public AssetReportTransaction paymentMeta(PaymentMeta paymentMeta)
@Nullable public PaymentMeta getPaymentMeta()
public void setPaymentMeta(PaymentMeta paymentMeta)
public AssetReportTransaction pending(Boolean pending)
public Boolean getPending()
public void setPending(Boolean pending)
public AssetReportTransaction pendingTransactionId(String pendingTransactionId)
@Nullable public String getPendingTransactionId()
public void setPendingTransactionId(String pendingTransactionId)
public AssetReportTransaction accountOwner(String accountOwner)
@Nullable public String getAccountOwner()
public void setAccountOwner(String accountOwner)
public AssetReportTransaction transactionId(String transactionId)
public String getTransactionId()
public void setTransactionId(String transactionId)
public AssetReportTransaction transactionType(AssetReportTransactionType transactionType)
@Nullable public AssetReportTransactionType getTransactionType()
public void setTransactionType(AssetReportTransactionType transactionType)
public AssetReportTransaction incomeSourceId(String incomeSourceId)
@Nullable public String getIncomeSourceId()
public void setIncomeSourceId(String incomeSourceId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.