public enum BankTransferNetwork extends Enum<BankTransferNetwork>
| Modifier and Type | Class and Description |
|---|---|
static class |
BankTransferNetwork.Adapter |
| Enum Constant and Description |
|---|
ACH |
ENUM_UNKNOWN |
SAME_DAY_ACH |
WIRE |
| Modifier and Type | Method and Description |
|---|---|
static BankTransferNetwork |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static BankTransferNetwork |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BankTransferNetwork[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BankTransferNetwork ACH
public static final BankTransferNetwork SAME_DAY_ACH
public static final BankTransferNetwork WIRE
public static final BankTransferNetwork ENUM_UNKNOWN
public static BankTransferNetwork[] values()
for (BankTransferNetwork c : BankTransferNetwork.values()) System.out.println(c);
public static BankTransferNetwork valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<BankTransferNetwork>public static BankTransferNetwork fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.