public enum BankTransferStatus extends Enum<BankTransferStatus>
| Modifier and Type | Class and Description |
|---|---|
static class |
BankTransferStatus.Adapter |
| Enum Constant and Description |
|---|
CANCELLED |
ENUM_UNKNOWN |
FAILED |
PENDING |
POSTED |
REVERSED |
| Modifier and Type | Method and Description |
|---|---|
static BankTransferStatus |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static BankTransferStatus |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BankTransferStatus[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BankTransferStatus PENDING
public static final BankTransferStatus POSTED
public static final BankTransferStatus CANCELLED
public static final BankTransferStatus FAILED
public static final BankTransferStatus REVERSED
public static final BankTransferStatus ENUM_UNKNOWN
public static BankTransferStatus[] values()
for (BankTransferStatus c : BankTransferStatus.values()) System.out.println(c);
public static BankTransferStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<BankTransferStatus>public static BankTransferStatus fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.