public enum BaseReportWarningCode extends Enum<BaseReportWarningCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
BaseReportWarningCode.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
OWNERS_UNAVAILABLE |
TRANSACTIONS_UNAVAILABLE |
| Modifier and Type | Method and Description |
|---|---|
static BaseReportWarningCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static BaseReportWarningCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BaseReportWarningCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BaseReportWarningCode OWNERS_UNAVAILABLE
public static final BaseReportWarningCode TRANSACTIONS_UNAVAILABLE
public static final BaseReportWarningCode ENUM_UNKNOWN
public static BaseReportWarningCode[] values()
for (BaseReportWarningCode c : BaseReportWarningCode.values()) System.out.println(c);
public static BaseReportWarningCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<BaseReportWarningCode>public static BaseReportWarningCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.