@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class CreditBankIncomeWebhookUpdateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_ENABLE_WEBHOOKS |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_USER_TOKEN |
| Constructor and Description |
|---|
CreditBankIncomeWebhookUpdateRequest() |
| Modifier and Type | Method and Description |
|---|---|
CreditBankIncomeWebhookUpdateRequest |
clientId(String clientId) |
CreditBankIncomeWebhookUpdateRequest |
enableWebhooks(Boolean enableWebhooks) |
boolean |
equals(Object o) |
String |
getClientId()
Your Plaid API `client_id`.
|
Boolean |
getEnableWebhooks()
Whether the user should be enabled for proactive webhook notifications when their income changes
|
String |
getSecret()
Your Plaid API `secret`.
|
String |
getUserToken()
The user token associated with the User data is being requested for.
|
int |
hashCode() |
CreditBankIncomeWebhookUpdateRequest |
secret(String secret) |
void |
setClientId(String clientId) |
void |
setEnableWebhooks(Boolean enableWebhooks) |
void |
setSecret(String secret) |
void |
setUserToken(String userToken) |
String |
toString() |
CreditBankIncomeWebhookUpdateRequest |
userToken(String userToken) |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_USER_TOKEN
public static final String SERIALIZED_NAME_ENABLE_WEBHOOKS
public CreditBankIncomeWebhookUpdateRequest()
public CreditBankIncomeWebhookUpdateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public CreditBankIncomeWebhookUpdateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public CreditBankIncomeWebhookUpdateRequest userToken(String userToken)
public String getUserToken()
public void setUserToken(String userToken)
public CreditBankIncomeWebhookUpdateRequest enableWebhooks(Boolean enableWebhooks)
public Boolean getEnableWebhooks()
public void setEnableWebhooks(Boolean enableWebhooks)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.