@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class CreditRelayCreateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_REPORT_TOKENS |
static String |
SERIALIZED_NAME_SECONDARY_CLIENT_ID |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_WEBHOOK |
| Constructor and Description |
|---|
CreditRelayCreateRequest() |
| Modifier and Type | Method and Description |
|---|---|
CreditRelayCreateRequest |
addReportTokensItem(String reportTokensItem) |
CreditRelayCreateRequest |
clientId(String clientId) |
boolean |
equals(Object o) |
String |
getClientId()
Your Plaid API `client_id`.
|
List<String> |
getReportTokens()
List of report token strings, with at most one token of each report type.
|
String |
getSecondaryClientId()
The `secondary_client_id` is the client id of the third party with whom you would like to share the relay token.
|
String |
getSecret()
Your Plaid API `secret`.
|
String |
getWebhook()
URL to which Plaid will send webhooks when the Secondary Client successfully retrieves an Asset Report by calling `/credit/relay/get`.
|
int |
hashCode() |
CreditRelayCreateRequest |
reportTokens(List<String> reportTokens) |
CreditRelayCreateRequest |
secondaryClientId(String secondaryClientId) |
CreditRelayCreateRequest |
secret(String secret) |
void |
setClientId(String clientId) |
void |
setReportTokens(List<String> reportTokens) |
void |
setSecondaryClientId(String secondaryClientId) |
void |
setSecret(String secret) |
void |
setWebhook(String webhook) |
String |
toString() |
CreditRelayCreateRequest |
webhook(String webhook) |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_REPORT_TOKENS
public static final String SERIALIZED_NAME_SECONDARY_CLIENT_ID
public static final String SERIALIZED_NAME_WEBHOOK
public CreditRelayCreateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public CreditRelayCreateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public CreditRelayCreateRequest reportTokens(List<String> reportTokens)
public CreditRelayCreateRequest addReportTokensItem(String reportTokensItem)
public List<String> getReportTokens()
public CreditRelayCreateRequest secondaryClientId(String secondaryClientId)
public String getSecondaryClientId()
public void setSecondaryClientId(String secondaryClientId)
public CreditRelayCreateRequest webhook(String webhook)
@Nullable public String getWebhook()
public void setWebhook(String webhook)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.