public static enum DepositSwitchCreateRequest.CountryCodeEnum extends Enum<DepositSwitchCreateRequest.CountryCodeEnum>
| Modifier and Type | Class and Description |
|---|---|
static class |
DepositSwitchCreateRequest.CountryCodeEnum.Adapter |
| Modifier and Type | Method and Description |
|---|---|
static DepositSwitchCreateRequest.CountryCodeEnum |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static DepositSwitchCreateRequest.CountryCodeEnum |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DepositSwitchCreateRequest.CountryCodeEnum[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final DepositSwitchCreateRequest.CountryCodeEnum US
public static final DepositSwitchCreateRequest.CountryCodeEnum CA
public static DepositSwitchCreateRequest.CountryCodeEnum[] values()
for (DepositSwitchCreateRequest.CountryCodeEnum c : DepositSwitchCreateRequest.CountryCodeEnum.values()) System.out.println(c);
public static DepositSwitchCreateRequest.CountryCodeEnum valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<DepositSwitchCreateRequest.CountryCodeEnum>public static DepositSwitchCreateRequest.CountryCodeEnum fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.