@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class DistributionBreakdown extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCOUNT_NAME |
static String |
SERIALIZED_NAME_BANK_NAME |
static String |
SERIALIZED_NAME_CURRENT_AMOUNT |
static String |
SERIALIZED_NAME_CURRENT_PAY |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_MASK |
static String |
SERIALIZED_NAME_TYPE |
static String |
SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE |
| Constructor and Description |
|---|
DistributionBreakdown() |
| Modifier and Type | Method and Description |
|---|---|
DistributionBreakdown |
accountName(String accountName) |
DistributionBreakdown |
bankName(String bankName) |
DistributionBreakdown |
currentAmount(Double currentAmount) |
DistributionBreakdown |
currentPay(Pay currentPay) |
boolean |
equals(Object o) |
String |
getAccountName()
Name of the account for the given distribution.
|
String |
getBankName()
The name of the bank that the payment is being deposited to.
|
Double |
getCurrentAmount()
The amount distributed to this account.
|
Pay |
getCurrentPay()
Get currentPay
|
String |
getIsoCurrencyCode()
The ISO-4217 currency code of the net pay.
|
String |
getMask()
The last 2-4 alphanumeric characters of an account's official account number.
|
String |
getType()
Type of the account that the paystub was sent to (e.g.
|
String |
getUnofficialCurrencyCode()
The unofficial currency code associated with the net pay.
|
int |
hashCode() |
DistributionBreakdown |
isoCurrencyCode(String isoCurrencyCode) |
DistributionBreakdown |
mask(String mask) |
void |
setAccountName(String accountName) |
void |
setBankName(String bankName) |
void |
setCurrentAmount(Double currentAmount) |
void |
setCurrentPay(Pay currentPay) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setMask(String mask) |
void |
setType(String type) |
void |
setUnofficialCurrencyCode(String unofficialCurrencyCode) |
String |
toString() |
DistributionBreakdown |
type(String type) |
DistributionBreakdown |
unofficialCurrencyCode(String unofficialCurrencyCode) |
public static final String SERIALIZED_NAME_ACCOUNT_NAME
public static final String SERIALIZED_NAME_BANK_NAME
public static final String SERIALIZED_NAME_CURRENT_AMOUNT
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_MASK
public static final String SERIALIZED_NAME_TYPE
public static final String SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE
public static final String SERIALIZED_NAME_CURRENT_PAY
public DistributionBreakdown accountName(String accountName)
@Nullable public String getAccountName()
public void setAccountName(String accountName)
public DistributionBreakdown bankName(String bankName)
@Nullable public String getBankName()
public void setBankName(String bankName)
public DistributionBreakdown currentAmount(Double currentAmount)
@Nullable public Double getCurrentAmount()
public void setCurrentAmount(Double currentAmount)
public DistributionBreakdown isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public DistributionBreakdown mask(String mask)
@Nullable public String getMask()
public void setMask(String mask)
public DistributionBreakdown type(String type)
@Nullable public String getType()
public void setType(String type)
public DistributionBreakdown unofficialCurrencyCode(String unofficialCurrencyCode)
@Nullable public String getUnofficialCurrencyCode()
public void setUnofficialCurrencyCode(String unofficialCurrencyCode)
public DistributionBreakdown currentPay(Pay currentPay)
public void setCurrentPay(Pay currentPay)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.