public enum DocumentDateOfBirthMatchCode extends Enum<DocumentDateOfBirthMatchCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
DocumentDateOfBirthMatchCode.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
MATCH |
NO_MATCH |
PARTIAL_MATCH |
| Modifier and Type | Method and Description |
|---|---|
static DocumentDateOfBirthMatchCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static DocumentDateOfBirthMatchCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DocumentDateOfBirthMatchCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final DocumentDateOfBirthMatchCode MATCH
public static final DocumentDateOfBirthMatchCode PARTIAL_MATCH
public static final DocumentDateOfBirthMatchCode NO_MATCH
public static final DocumentDateOfBirthMatchCode ENUM_UNKNOWN
public static DocumentDateOfBirthMatchCode[] values()
for (DocumentDateOfBirthMatchCode c : DocumentDateOfBirthMatchCode.values()) System.out.println(c);
public static DocumentDateOfBirthMatchCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<DocumentDateOfBirthMatchCode>public static DocumentDateOfBirthMatchCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.