public enum DocumentNameMatchCode extends Enum<DocumentNameMatchCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
DocumentNameMatchCode.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
MATCH |
NO_MATCH |
PARTIAL_MATCH |
| Modifier and Type | Method and Description |
|---|---|
static DocumentNameMatchCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static DocumentNameMatchCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DocumentNameMatchCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final DocumentNameMatchCode MATCH
public static final DocumentNameMatchCode PARTIAL_MATCH
public static final DocumentNameMatchCode NO_MATCH
public static final DocumentNameMatchCode ENUM_UNKNOWN
public static DocumentNameMatchCode[] values()
for (DocumentNameMatchCode c : DocumentNameMatchCode.values()) System.out.println(c);
public static DocumentNameMatchCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<DocumentNameMatchCode>public static DocumentNameMatchCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.