@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class Email extends Object
| Modifier and Type | Class and Description |
|---|---|
static class |
Email.TypeEnum
The type of email account as described by the financial institution.
|
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_DATA |
static String |
SERIALIZED_NAME_PRIMARY |
static String |
SERIALIZED_NAME_TYPE |
| Constructor and Description |
|---|
Email() |
| Modifier and Type | Method and Description |
|---|---|
Email |
data(String data) |
boolean |
equals(Object o) |
String |
getData()
The email address.
|
Boolean |
getPrimary()
When `true`, identifies the email address as the primary email on an account.
|
Email.TypeEnum |
getType()
The type of email account as described by the financial institution.
|
int |
hashCode() |
Email |
primary(Boolean primary) |
void |
setData(String data) |
void |
setPrimary(Boolean primary) |
void |
setType(Email.TypeEnum type) |
String |
toString() |
Email |
type(Email.TypeEnum type) |
public static final String SERIALIZED_NAME_DATA
public static final String SERIALIZED_NAME_PRIMARY
public static final String SERIALIZED_NAME_TYPE
public String getData()
public void setData(String data)
public Boolean getPrimary()
public void setPrimary(Boolean primary)
public Email type(Email.TypeEnum type)
public Email.TypeEnum getType()
public void setType(Email.TypeEnum type)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.