public enum EntityWatchlistCode extends Enum<EntityWatchlistCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
EntityWatchlistCode.Adapter |
| Enum Constant and Description |
|---|
AU_CON |
CA_CON |
ENUM_UNKNOWN |
EU_CON |
IZ_SOE |
IZ_UNC |
IZ_WBK |
UK_HMC |
US_CAP |
US_CMC |
US_FSE |
US_MBS |
US_SDN |
US_SSI |
US_UVL |
| Modifier and Type | Method and Description |
|---|---|
static EntityWatchlistCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static EntityWatchlistCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static EntityWatchlistCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final EntityWatchlistCode CA_CON
public static final EntityWatchlistCode EU_CON
public static final EntityWatchlistCode IZ_SOE
public static final EntityWatchlistCode IZ_UNC
public static final EntityWatchlistCode IZ_WBK
public static final EntityWatchlistCode US_CAP
public static final EntityWatchlistCode US_FSE
public static final EntityWatchlistCode US_MBS
public static final EntityWatchlistCode US_SDN
public static final EntityWatchlistCode US_SSI
public static final EntityWatchlistCode US_CMC
public static final EntityWatchlistCode US_UVL
public static final EntityWatchlistCode AU_CON
public static final EntityWatchlistCode UK_HMC
public static final EntityWatchlistCode ENUM_UNKNOWN
public static EntityWatchlistCode[] values()
for (EntityWatchlistCode c : EntityWatchlistCode.values()) System.out.println(c);
public static EntityWatchlistCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<EntityWatchlistCode>public static EntityWatchlistCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.