public enum HostedLinkDeliveryMethod extends Enum<HostedLinkDeliveryMethod>
| Modifier and Type | Class and Description |
|---|---|
static class |
HostedLinkDeliveryMethod.Adapter |
| Enum Constant and Description |
|---|
EMAIL |
ENUM_UNKNOWN |
SMS |
| Modifier and Type | Method and Description |
|---|---|
static HostedLinkDeliveryMethod |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static HostedLinkDeliveryMethod |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static HostedLinkDeliveryMethod[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final HostedLinkDeliveryMethod SMS
public static final HostedLinkDeliveryMethod EMAIL
public static final HostedLinkDeliveryMethod ENUM_UNKNOWN
public static HostedLinkDeliveryMethod[] values()
for (HostedLinkDeliveryMethod c : HostedLinkDeliveryMethod.values()) System.out.println(c);
public static HostedLinkDeliveryMethod valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<HostedLinkDeliveryMethod>public static HostedLinkDeliveryMethod fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.