public enum ISOCurrencyCode extends Enum<ISOCurrencyCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
ISOCurrencyCode.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
USD |
| Modifier and Type | Method and Description |
|---|---|
static ISOCurrencyCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static ISOCurrencyCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static ISOCurrencyCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ISOCurrencyCode USD
public static final ISOCurrencyCode ENUM_UNKNOWN
public static ISOCurrencyCode[] values()
for (ISOCurrencyCode c : ISOCurrencyCode.values()) System.out.println(c);
public static ISOCurrencyCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<ISOCurrencyCode>public static ISOCurrencyCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.