@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class IdentityMatchResponse extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCOUNTS |
static String |
SERIALIZED_NAME_ITEM |
static String |
SERIALIZED_NAME_REQUEST_ID |
| Constructor and Description |
|---|
IdentityMatchResponse() |
| Modifier and Type | Method and Description |
|---|---|
IdentityMatchResponse |
accounts(List<AccountIdentityMatchScore> accounts) |
IdentityMatchResponse |
addAccountsItem(AccountIdentityMatchScore accountsItem) |
boolean |
equals(Object o) |
List<AccountIdentityMatchScore> |
getAccounts()
The accounts for which Identity match has been requested
|
Item |
getItem()
Get item
|
String |
getRequestId()
A unique identifier for the request, which can be used for troubleshooting.
|
int |
hashCode() |
IdentityMatchResponse |
item(Item item) |
IdentityMatchResponse |
requestId(String requestId) |
void |
setAccounts(List<AccountIdentityMatchScore> accounts) |
void |
setItem(Item item) |
void |
setRequestId(String requestId) |
String |
toString() |
public static final String SERIALIZED_NAME_ACCOUNTS
public static final String SERIALIZED_NAME_ITEM
public static final String SERIALIZED_NAME_REQUEST_ID
public IdentityMatchResponse accounts(List<AccountIdentityMatchScore> accounts)
public IdentityMatchResponse addAccountsItem(AccountIdentityMatchScore accountsItem)
public List<AccountIdentityMatchScore> getAccounts()
public void setAccounts(List<AccountIdentityMatchScore> accounts)
public IdentityMatchResponse item(Item item)
public Item getItem()
public void setItem(Item item)
public IdentityMatchResponse requestId(String requestId)
public String getRequestId()
public void setRequestId(String requestId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.