@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class IdentityVerificationCreateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_CLIENT_USER_ID |
static String |
SERIALIZED_NAME_GAVE_CONSENT |
static String |
SERIALIZED_NAME_IS_IDEMPOTENT |
static String |
SERIALIZED_NAME_IS_SHAREABLE |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_TEMPLATE_ID |
static String |
SERIALIZED_NAME_USER |
| Constructor and Description |
|---|
IdentityVerificationCreateRequest() |
| Modifier and Type | Method and Description |
|---|---|
IdentityVerificationCreateRequest |
clientId(String clientId) |
IdentityVerificationCreateRequest |
clientUserId(String clientUserId) |
boolean |
equals(Object o) |
IdentityVerificationCreateRequest |
gaveConsent(Boolean gaveConsent) |
String |
getClientId()
Your Plaid API `client_id`.
|
String |
getClientUserId()
A unique ID that identifies the end user in your system.
|
Boolean |
getGaveConsent()
A flag specifying whether the end user has already agreed to a privacy policy specifying that their data will be shared with Plaid for verification purposes.
|
Boolean |
getIsIdempotent()
An optional flag specifying how you would like Plaid to handle attempts to create an Identity Verification when an Identity Verification already exists for the provided `client_user_id` and `template_id`.
|
Boolean |
getIsShareable()
A flag specifying whether you would like Plaid to expose a shareable URL for the verification being created.
|
String |
getSecret()
Your Plaid API `secret`.
|
String |
getTemplateId()
ID of the associated Identity Verification template.
|
IdentityVerificationCreateRequestUser |
getUser()
Get user
|
int |
hashCode() |
IdentityVerificationCreateRequest |
isIdempotent(Boolean isIdempotent) |
IdentityVerificationCreateRequest |
isShareable(Boolean isShareable) |
IdentityVerificationCreateRequest |
secret(String secret) |
void |
setClientId(String clientId) |
void |
setClientUserId(String clientUserId) |
void |
setGaveConsent(Boolean gaveConsent) |
void |
setIsIdempotent(Boolean isIdempotent) |
void |
setIsShareable(Boolean isShareable) |
void |
setSecret(String secret) |
void |
setTemplateId(String templateId) |
void |
setUser(IdentityVerificationCreateRequestUser user) |
IdentityVerificationCreateRequest |
templateId(String templateId) |
String |
toString() |
IdentityVerificationCreateRequest |
user(IdentityVerificationCreateRequestUser user) |
public static final String SERIALIZED_NAME_CLIENT_USER_ID
public static final String SERIALIZED_NAME_IS_SHAREABLE
public static final String SERIALIZED_NAME_TEMPLATE_ID
public static final String SERIALIZED_NAME_GAVE_CONSENT
public static final String SERIALIZED_NAME_USER
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_IS_IDEMPOTENT
public IdentityVerificationCreateRequest clientUserId(String clientUserId)
@Nullable public String getClientUserId()
public void setClientUserId(String clientUserId)
public IdentityVerificationCreateRequest isShareable(Boolean isShareable)
public Boolean getIsShareable()
public void setIsShareable(Boolean isShareable)
public IdentityVerificationCreateRequest templateId(String templateId)
public String getTemplateId()
public void setTemplateId(String templateId)
public IdentityVerificationCreateRequest gaveConsent(Boolean gaveConsent)
public Boolean getGaveConsent()
public void setGaveConsent(Boolean gaveConsent)
public IdentityVerificationCreateRequest user(IdentityVerificationCreateRequestUser user)
@Nullable public IdentityVerificationCreateRequestUser getUser()
public void setUser(IdentityVerificationCreateRequestUser user)
public IdentityVerificationCreateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public IdentityVerificationCreateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public IdentityVerificationCreateRequest isIdempotent(Boolean isIdempotent)
@Nullable public Boolean getIsIdempotent()
public void setIsIdempotent(Boolean isIdempotent)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.