@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class IdentityVerificationRetryRequestStepsObject extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_DOCUMENTARY_VERIFICATION |
static String |
SERIALIZED_NAME_KYC_CHECK |
static String |
SERIALIZED_NAME_SELFIE_CHECK |
static String |
SERIALIZED_NAME_VERIFY_SMS |
| Constructor and Description |
|---|
IdentityVerificationRetryRequestStepsObject() |
| Modifier and Type | Method and Description |
|---|---|
IdentityVerificationRetryRequestStepsObject |
documentaryVerification(Boolean documentaryVerification) |
boolean |
equals(Object o) |
Boolean |
getDocumentaryVerification()
A boolean field specifying whether the new session should require or skip the `documentary_verification` step.
|
Boolean |
getKycCheck()
A boolean field specifying whether the new session should require or skip the `kyc_check` step.
|
Boolean |
getSelfieCheck()
A boolean field specifying whether the new session should require or skip the `selfie_check` step.
|
Boolean |
getVerifySms()
A boolean field specifying whether the new session should require or skip the `verify_sms` step.
|
int |
hashCode() |
IdentityVerificationRetryRequestStepsObject |
kycCheck(Boolean kycCheck) |
IdentityVerificationRetryRequestStepsObject |
selfieCheck(Boolean selfieCheck) |
void |
setDocumentaryVerification(Boolean documentaryVerification) |
void |
setKycCheck(Boolean kycCheck) |
void |
setSelfieCheck(Boolean selfieCheck) |
void |
setVerifySms(Boolean verifySms) |
String |
toString() |
IdentityVerificationRetryRequestStepsObject |
verifySms(Boolean verifySms) |
public static final String SERIALIZED_NAME_VERIFY_SMS
public static final String SERIALIZED_NAME_KYC_CHECK
public static final String SERIALIZED_NAME_DOCUMENTARY_VERIFICATION
public static final String SERIALIZED_NAME_SELFIE_CHECK
public IdentityVerificationRetryRequestStepsObject()
public IdentityVerificationRetryRequestStepsObject verifySms(Boolean verifySms)
public Boolean getVerifySms()
public void setVerifySms(Boolean verifySms)
public IdentityVerificationRetryRequestStepsObject kycCheck(Boolean kycCheck)
public Boolean getKycCheck()
public void setKycCheck(Boolean kycCheck)
public IdentityVerificationRetryRequestStepsObject documentaryVerification(Boolean documentaryVerification)
public Boolean getDocumentaryVerification()
public void setDocumentaryVerification(Boolean documentaryVerification)
public IdentityVerificationRetryRequestStepsObject selfieCheck(Boolean selfieCheck)
public Boolean getSelfieCheck()
public void setSelfieCheck(Boolean selfieCheck)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.