@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class IndividualName extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_FIRST_NAME |
static String |
SERIALIZED_NAME_LAST_NAME |
| Constructor and Description |
|---|
IndividualName() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object o) |
IndividualName |
firstName(String firstName) |
String |
getFirstName()
The first name of the individual represented by the parent object.
|
String |
getLastName()
The last name of the individual represented by the parent object.
|
int |
hashCode() |
IndividualName |
lastName(String lastName) |
void |
setFirstName(String firstName) |
void |
setLastName(String lastName) |
String |
toString() |
public static final String SERIALIZED_NAME_FIRST_NAME
public static final String SERIALIZED_NAME_LAST_NAME
public IndividualName firstName(String firstName)
public String getFirstName()
public void setFirstName(String firstName)
public IndividualName lastName(String lastName)
public String getLastName()
public void setLastName(String lastName)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.