@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class ItemApplicationScopesUpdateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCESS_TOKEN |
static String |
SERIALIZED_NAME_APPLICATION_ID |
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_CONTEXT |
static String |
SERIALIZED_NAME_SCOPES |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_STATE |
| Constructor and Description |
|---|
ItemApplicationScopesUpdateRequest() |
| Modifier and Type | Method and Description |
|---|---|
ItemApplicationScopesUpdateRequest |
accessToken(String accessToken) |
ItemApplicationScopesUpdateRequest |
applicationId(String applicationId) |
ItemApplicationScopesUpdateRequest |
clientId(String clientId) |
ItemApplicationScopesUpdateRequest |
context(ScopesContext context) |
boolean |
equals(Object o) |
String |
getAccessToken()
The access token associated with the Item data is being requested for.
|
String |
getApplicationId()
This field will map to the application ID that is returned from /item/applications/list, or provided to the institution in an oauth redirect.
|
String |
getClientId()
Your Plaid API `client_id`.
|
ScopesContext |
getContext()
Get context
|
Scopes |
getScopes()
Get scopes
|
String |
getSecret()
Your Plaid API `secret`.
|
String |
getState()
When scopes are updated during enrollment, this field must be populated with the state sent to the partner in the OAuth Login URI.
|
int |
hashCode() |
ItemApplicationScopesUpdateRequest |
scopes(Scopes scopes) |
ItemApplicationScopesUpdateRequest |
secret(String secret) |
void |
setAccessToken(String accessToken) |
void |
setApplicationId(String applicationId) |
void |
setClientId(String clientId) |
void |
setContext(ScopesContext context) |
void |
setScopes(Scopes scopes) |
void |
setSecret(String secret) |
void |
setState(String state) |
ItemApplicationScopesUpdateRequest |
state(String state) |
String |
toString() |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_ACCESS_TOKEN
public static final String SERIALIZED_NAME_APPLICATION_ID
public static final String SERIALIZED_NAME_SCOPES
public static final String SERIALIZED_NAME_STATE
public static final String SERIALIZED_NAME_CONTEXT
public ItemApplicationScopesUpdateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public ItemApplicationScopesUpdateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public ItemApplicationScopesUpdateRequest accessToken(String accessToken)
public String getAccessToken()
public void setAccessToken(String accessToken)
public ItemApplicationScopesUpdateRequest applicationId(String applicationId)
public String getApplicationId()
public void setApplicationId(String applicationId)
public ItemApplicationScopesUpdateRequest scopes(Scopes scopes)
public Scopes getScopes()
public void setScopes(Scopes scopes)
public ItemApplicationScopesUpdateRequest state(String state)
@Nullable public String getState()
public void setState(String state)
public ItemApplicationScopesUpdateRequest context(ScopesContext context)
public ScopesContext getContext()
public void setContext(ScopesContext context)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.