public enum LinkDeliveryWebhookCommunicationMethod extends Enum<LinkDeliveryWebhookCommunicationMethod>
| Modifier and Type | Class and Description |
|---|---|
static class |
LinkDeliveryWebhookCommunicationMethod.Adapter |
| Enum Constant and Description |
|---|
EMAIL |
ENUM_UNKNOWN |
SMS |
| Modifier and Type | Method and Description |
|---|---|
static LinkDeliveryWebhookCommunicationMethod |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static LinkDeliveryWebhookCommunicationMethod |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static LinkDeliveryWebhookCommunicationMethod[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final LinkDeliveryWebhookCommunicationMethod SMS
public static final LinkDeliveryWebhookCommunicationMethod EMAIL
public static final LinkDeliveryWebhookCommunicationMethod ENUM_UNKNOWN
public static LinkDeliveryWebhookCommunicationMethod[] values()
for (LinkDeliveryWebhookCommunicationMethod c : LinkDeliveryWebhookCommunicationMethod.values()) System.out.println(c);
public static LinkDeliveryWebhookCommunicationMethod valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<LinkDeliveryWebhookCommunicationMethod>public static LinkDeliveryWebhookCommunicationMethod fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.