@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class LinkTokenCreateRequestAuth extends Object
| Modifier and Type | Class and Description |
|---|---|
static class |
LinkTokenCreateRequestAuth.FlowTypeEnum
This field has been deprecated in favor of `auth_type_select_enabled`.
|
static class |
LinkTokenCreateRequestAuth.RerouteToCredentialsEnum
Specifies what type of [Reroute to Credentials](https://plaid.com/docs/auth/coverage/same-day/#reroute-to-credentials) pane should be used in the Link session for the Same Day Micro-deposits flow.
|
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AUTH_TYPE_SELECT_ENABLED |
static String |
SERIALIZED_NAME_AUTOMATED_MICRODEPOSITS_ENABLED |
static String |
SERIALIZED_NAME_FLOW_TYPE |
static String |
SERIALIZED_NAME_INSTANT_MATCH_ENABLED |
static String |
SERIALIZED_NAME_REROUTE_TO_CREDENTIALS |
static String |
SERIALIZED_NAME_SAME_DAY_MICRODEPOSITS_ENABLED |
| Constructor and Description |
|---|
LinkTokenCreateRequestAuth() |
| Modifier and Type | Method and Description |
|---|---|
LinkTokenCreateRequestAuth |
authTypeSelectEnabled(Boolean authTypeSelectEnabled) |
LinkTokenCreateRequestAuth |
automatedMicrodepositsEnabled(Boolean automatedMicrodepositsEnabled) |
boolean |
equals(Object o) |
LinkTokenCreateRequestAuth |
flowType(LinkTokenCreateRequestAuth.FlowTypeEnum flowType) |
Boolean |
getAuthTypeSelectEnabled()
Specifies whether Auth Type Select is enabled for the Link session, allowing the end user to choose between linking instantly or manually prior to selecting their financial institution.
|
Boolean |
getAutomatedMicrodepositsEnabled()
Specifies whether the Link session is enabled for the Automated Micro-deposits flow.
|
LinkTokenCreateRequestAuth.FlowTypeEnum |
getFlowType()
This field has been deprecated in favor of `auth_type_select_enabled`.
|
Boolean |
getInstantMatchEnabled()
Specifies whether the Link session is enabled for the Instant Match flow.
|
LinkTokenCreateRequestAuth.RerouteToCredentialsEnum |
getRerouteToCredentials()
Specifies what type of [Reroute to Credentials](https://plaid.com/docs/auth/coverage/same-day/#reroute-to-credentials) pane should be used in the Link session for the Same Day Micro-deposits flow.
|
Boolean |
getSameDayMicrodepositsEnabled()
Specifies whether the Link session is enabled for the Same Day Micro-deposits flow.
|
int |
hashCode() |
LinkTokenCreateRequestAuth |
instantMatchEnabled(Boolean instantMatchEnabled) |
LinkTokenCreateRequestAuth |
rerouteToCredentials(LinkTokenCreateRequestAuth.RerouteToCredentialsEnum rerouteToCredentials) |
LinkTokenCreateRequestAuth |
sameDayMicrodepositsEnabled(Boolean sameDayMicrodepositsEnabled) |
void |
setAuthTypeSelectEnabled(Boolean authTypeSelectEnabled) |
void |
setAutomatedMicrodepositsEnabled(Boolean automatedMicrodepositsEnabled) |
void |
setFlowType(LinkTokenCreateRequestAuth.FlowTypeEnum flowType) |
void |
setInstantMatchEnabled(Boolean instantMatchEnabled) |
void |
setRerouteToCredentials(LinkTokenCreateRequestAuth.RerouteToCredentialsEnum rerouteToCredentials) |
void |
setSameDayMicrodepositsEnabled(Boolean sameDayMicrodepositsEnabled) |
String |
toString() |
public static final String SERIALIZED_NAME_AUTH_TYPE_SELECT_ENABLED
public static final String SERIALIZED_NAME_AUTOMATED_MICRODEPOSITS_ENABLED
public static final String SERIALIZED_NAME_INSTANT_MATCH_ENABLED
public static final String SERIALIZED_NAME_SAME_DAY_MICRODEPOSITS_ENABLED
public static final String SERIALIZED_NAME_REROUTE_TO_CREDENTIALS
public static final String SERIALIZED_NAME_FLOW_TYPE
public LinkTokenCreateRequestAuth authTypeSelectEnabled(Boolean authTypeSelectEnabled)
@Nullable public Boolean getAuthTypeSelectEnabled()
public void setAuthTypeSelectEnabled(Boolean authTypeSelectEnabled)
public LinkTokenCreateRequestAuth automatedMicrodepositsEnabled(Boolean automatedMicrodepositsEnabled)
@Nullable public Boolean getAutomatedMicrodepositsEnabled()
public void setAutomatedMicrodepositsEnabled(Boolean automatedMicrodepositsEnabled)
public LinkTokenCreateRequestAuth instantMatchEnabled(Boolean instantMatchEnabled)
@Nullable public Boolean getInstantMatchEnabled()
public void setInstantMatchEnabled(Boolean instantMatchEnabled)
public LinkTokenCreateRequestAuth sameDayMicrodepositsEnabled(Boolean sameDayMicrodepositsEnabled)
@Nullable public Boolean getSameDayMicrodepositsEnabled()
public void setSameDayMicrodepositsEnabled(Boolean sameDayMicrodepositsEnabled)
public LinkTokenCreateRequestAuth rerouteToCredentials(LinkTokenCreateRequestAuth.RerouteToCredentialsEnum rerouteToCredentials)
@Nullable public LinkTokenCreateRequestAuth.RerouteToCredentialsEnum getRerouteToCredentials()
public void setRerouteToCredentials(LinkTokenCreateRequestAuth.RerouteToCredentialsEnum rerouteToCredentials)
public LinkTokenCreateRequestAuth flowType(LinkTokenCreateRequestAuth.FlowTypeEnum flowType)
@Nullable public LinkTokenCreateRequestAuth.FlowTypeEnum getFlowType()
public void setFlowType(LinkTokenCreateRequestAuth.FlowTypeEnum flowType)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.