@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class LinkTokenCreateRequestIdentityVerification extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CONSENT |
static String |
SERIALIZED_NAME_GAVE_CONSENT |
static String |
SERIALIZED_NAME_TEMPLATE_ID |
| Constructor and Description |
|---|
LinkTokenCreateRequestIdentityVerification() |
| Modifier and Type | Method and Description |
|---|---|
LinkTokenCreateRequestIdentityVerification |
consent(Boolean consent) |
boolean |
equals(Object o) |
LinkTokenCreateRequestIdentityVerification |
gaveConsent(Boolean gaveConsent) |
Boolean |
getConsent()
Get consent
|
Boolean |
getGaveConsent()
A flag specifying whether the end user has already agreed to a privacy policy specifying that their data will be shared with Plaid for verification purposes.
|
String |
getTemplateId()
ID of the associated Identity Verification template.
|
int |
hashCode() |
void |
setConsent(Boolean consent) |
void |
setGaveConsent(Boolean gaveConsent) |
void |
setTemplateId(String templateId) |
LinkTokenCreateRequestIdentityVerification |
templateId(String templateId) |
String |
toString() |
public static final String SERIALIZED_NAME_TEMPLATE_ID
public static final String SERIALIZED_NAME_CONSENT
public static final String SERIALIZED_NAME_GAVE_CONSENT
public LinkTokenCreateRequestIdentityVerification()
public LinkTokenCreateRequestIdentityVerification templateId(String templateId)
public String getTemplateId()
public void setTemplateId(String templateId)
public LinkTokenCreateRequestIdentityVerification consent(Boolean consent)
public void setConsent(Boolean consent)
public LinkTokenCreateRequestIdentityVerification gaveConsent(Boolean gaveConsent)
@Nullable public Boolean getGaveConsent()
public void setGaveConsent(Boolean gaveConsent)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.