public enum PartnerEndCustomerFlowdownStatus extends Enum<PartnerEndCustomerFlowdownStatus>
| Modifier and Type | Class and Description |
|---|---|
static class |
PartnerEndCustomerFlowdownStatus.Adapter |
| Enum Constant and Description |
|---|
COMPLETE |
ENUM_UNKNOWN |
IN_REVIEW |
NEGOTIATION |
NOT_STARTED |
| Modifier and Type | Method and Description |
|---|---|
static PartnerEndCustomerFlowdownStatus |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static PartnerEndCustomerFlowdownStatus |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PartnerEndCustomerFlowdownStatus[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PartnerEndCustomerFlowdownStatus NOT_STARTED
public static final PartnerEndCustomerFlowdownStatus IN_REVIEW
public static final PartnerEndCustomerFlowdownStatus NEGOTIATION
public static final PartnerEndCustomerFlowdownStatus COMPLETE
public static final PartnerEndCustomerFlowdownStatus ENUM_UNKNOWN
public static PartnerEndCustomerFlowdownStatus[] values()
for (PartnerEndCustomerFlowdownStatus c : PartnerEndCustomerFlowdownStatus.values()) System.out.println(c);
public static PartnerEndCustomerFlowdownStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<PartnerEndCustomerFlowdownStatus>public static PartnerEndCustomerFlowdownStatus fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.