public enum PartnerEndCustomerOAuthStatusUpdatedValues extends Enum<PartnerEndCustomerOAuthStatusUpdatedValues>
| Modifier and Type | Class and Description |
|---|---|
static class |
PartnerEndCustomerOAuthStatusUpdatedValues.Adapter |
| Enum Constant and Description |
|---|
APPROVED |
ATTENTION_REQUIRED |
ENABLED |
ENUM_UNKNOWN |
NOT_STARTED |
PROCESSING |
| Modifier and Type | Method and Description |
|---|---|
static PartnerEndCustomerOAuthStatusUpdatedValues |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static PartnerEndCustomerOAuthStatusUpdatedValues |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PartnerEndCustomerOAuthStatusUpdatedValues[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PartnerEndCustomerOAuthStatusUpdatedValues NOT_STARTED
public static final PartnerEndCustomerOAuthStatusUpdatedValues PROCESSING
public static final PartnerEndCustomerOAuthStatusUpdatedValues APPROVED
public static final PartnerEndCustomerOAuthStatusUpdatedValues ENABLED
public static final PartnerEndCustomerOAuthStatusUpdatedValues ATTENTION_REQUIRED
public static final PartnerEndCustomerOAuthStatusUpdatedValues ENUM_UNKNOWN
public static PartnerEndCustomerOAuthStatusUpdatedValues[] values()
for (PartnerEndCustomerOAuthStatusUpdatedValues c : PartnerEndCustomerOAuthStatusUpdatedValues.values()) System.out.println(c);
public static PartnerEndCustomerOAuthStatusUpdatedValues valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<PartnerEndCustomerOAuthStatusUpdatedValues>public static PartnerEndCustomerOAuthStatusUpdatedValues fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.