public enum PartnerEndCustomerStatus extends Enum<PartnerEndCustomerStatus>
| Modifier and Type | Class and Description |
|---|---|
static class |
PartnerEndCustomerStatus.Adapter |
| Enum Constant and Description |
|---|
ACTIVE |
DENIED |
ENUM_UNKNOWN |
PENDING_ENABLEMENT |
UNDER_REVIEW |
| Modifier and Type | Method and Description |
|---|---|
static PartnerEndCustomerStatus |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static PartnerEndCustomerStatus |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PartnerEndCustomerStatus[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PartnerEndCustomerStatus UNDER_REVIEW
public static final PartnerEndCustomerStatus PENDING_ENABLEMENT
public static final PartnerEndCustomerStatus ACTIVE
public static final PartnerEndCustomerStatus DENIED
public static final PartnerEndCustomerStatus ENUM_UNKNOWN
public static PartnerEndCustomerStatus[] values()
for (PartnerEndCustomerStatus c : PartnerEndCustomerStatus.values()) System.out.println(c);
public static PartnerEndCustomerStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<PartnerEndCustomerStatus>public static PartnerEndCustomerStatus fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.