@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class PhysicalDocumentImages extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CROPPED_BACK |
static String |
SERIALIZED_NAME_CROPPED_FRONT |
static String |
SERIALIZED_NAME_FACE |
static String |
SERIALIZED_NAME_ORIGINAL_BACK |
static String |
SERIALIZED_NAME_ORIGINAL_FRONT |
| Constructor and Description |
|---|
PhysicalDocumentImages() |
| Modifier and Type | Method and Description |
|---|---|
PhysicalDocumentImages |
croppedBack(String croppedBack) |
PhysicalDocumentImages |
croppedFront(String croppedFront) |
boolean |
equals(Object o) |
PhysicalDocumentImages |
face(String face) |
String |
getCroppedBack()
Temporary URL that expires after 60 seconds for downloading a cropped image containing just the back of the document.
|
String |
getCroppedFront()
Temporary URL that expires after 60 seconds for downloading a cropped image containing just the front of the document.
|
String |
getFace()
Temporary URL that expires after 60 seconds for downloading a crop of just the user's face from the document image.
|
String |
getOriginalBack()
Temporary URL that expires after 60 seconds for downloading the original image of the back of the document.
|
String |
getOriginalFront()
Temporary URL that expires after 60 seconds for downloading the uncropped original image of the front of the document.
|
int |
hashCode() |
PhysicalDocumentImages |
originalBack(String originalBack) |
PhysicalDocumentImages |
originalFront(String originalFront) |
void |
setCroppedBack(String croppedBack) |
void |
setCroppedFront(String croppedFront) |
void |
setFace(String face) |
void |
setOriginalBack(String originalBack) |
void |
setOriginalFront(String originalFront) |
String |
toString() |
public static final String SERIALIZED_NAME_ORIGINAL_FRONT
public static final String SERIALIZED_NAME_ORIGINAL_BACK
public static final String SERIALIZED_NAME_CROPPED_FRONT
public static final String SERIALIZED_NAME_CROPPED_BACK
public static final String SERIALIZED_NAME_FACE
public PhysicalDocumentImages originalFront(String originalFront)
@Nullable public String getOriginalFront()
public void setOriginalFront(String originalFront)
public PhysicalDocumentImages originalBack(String originalBack)
@Nullable public String getOriginalBack()
public void setOriginalBack(String originalBack)
public PhysicalDocumentImages croppedFront(String croppedFront)
@Nullable public String getCroppedFront()
public void setCroppedFront(String croppedFront)
public PhysicalDocumentImages croppedBack(String croppedBack)
@Nullable public String getCroppedBack()
public void setCroppedBack(String croppedBack)
public PhysicalDocumentImages face(String face)
@Nullable public String getFace()
public void setFace(String face)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.