@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class PlaidError extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CAUSES |
static String |
SERIALIZED_NAME_DISPLAY_MESSAGE |
static String |
SERIALIZED_NAME_DOCUMENTATION_URL |
static String |
SERIALIZED_NAME_ERROR_CODE |
static String |
SERIALIZED_NAME_ERROR_MESSAGE |
static String |
SERIALIZED_NAME_ERROR_TYPE |
static String |
SERIALIZED_NAME_REQUEST_ID |
static String |
SERIALIZED_NAME_STATUS |
static String |
SERIALIZED_NAME_SUGGESTED_ACTION |
| Constructor and Description |
|---|
PlaidError() |
| Modifier and Type | Method and Description |
|---|---|
PlaidError |
addCausesItem(Object causesItem) |
PlaidError |
causes(List<Object> causes) |
PlaidError |
displayMessage(String displayMessage) |
PlaidError |
documentationUrl(String documentationUrl) |
boolean |
equals(Object o) |
PlaidError |
errorCode(String errorCode) |
PlaidError |
errorMessage(String errorMessage) |
PlaidError |
errorType(PlaidErrorType errorType) |
List<Object> |
getCauses()
In the Assets product, a request can pertain to more than one Item.
|
String |
getDisplayMessage()
A user-friendly representation of the error code.
|
String |
getDocumentationUrl()
The URL of a Plaid documentation page with more information about the error
|
String |
getErrorCode()
The particular error code.
|
String |
getErrorMessage()
A developer-friendly representation of the error code.
|
PlaidErrorType |
getErrorType()
Get errorType
|
String |
getRequestId()
A unique ID identifying the request, to be used for troubleshooting purposes.
|
Integer |
getStatus()
The HTTP status code associated with the error.
|
String |
getSuggestedAction()
Suggested steps for resolving the error
|
int |
hashCode() |
PlaidError |
requestId(String requestId) |
void |
setCauses(List<Object> causes) |
void |
setDisplayMessage(String displayMessage) |
void |
setDocumentationUrl(String documentationUrl) |
void |
setErrorCode(String errorCode) |
void |
setErrorMessage(String errorMessage) |
void |
setErrorType(PlaidErrorType errorType) |
void |
setRequestId(String requestId) |
void |
setStatus(Integer status) |
void |
setSuggestedAction(String suggestedAction) |
PlaidError |
status(Integer status) |
PlaidError |
suggestedAction(String suggestedAction) |
String |
toString() |
public static final String SERIALIZED_NAME_ERROR_TYPE
public static final String SERIALIZED_NAME_ERROR_CODE
public static final String SERIALIZED_NAME_ERROR_MESSAGE
public static final String SERIALIZED_NAME_DISPLAY_MESSAGE
public static final String SERIALIZED_NAME_REQUEST_ID
public static final String SERIALIZED_NAME_CAUSES
public static final String SERIALIZED_NAME_STATUS
public static final String SERIALIZED_NAME_DOCUMENTATION_URL
public static final String SERIALIZED_NAME_SUGGESTED_ACTION
public PlaidError errorType(PlaidErrorType errorType)
public PlaidErrorType getErrorType()
public void setErrorType(PlaidErrorType errorType)
public PlaidError errorCode(String errorCode)
public String getErrorCode()
public void setErrorCode(String errorCode)
public PlaidError errorMessage(String errorMessage)
public String getErrorMessage()
public void setErrorMessage(String errorMessage)
public PlaidError displayMessage(String displayMessage)
@Nullable public String getDisplayMessage()
public void setDisplayMessage(String displayMessage)
public PlaidError requestId(String requestId)
@Nullable public String getRequestId()
public void setRequestId(String requestId)
public PlaidError causes(List<Object> causes)
public PlaidError addCausesItem(Object causesItem)
@Nullable public List<Object> getCauses()
public PlaidError status(Integer status)
@Nullable public Integer getStatus()
public void setStatus(Integer status)
public PlaidError documentationUrl(String documentationUrl)
@Nullable public String getDocumentationUrl()
public void setDocumentationUrl(String documentationUrl)
public PlaidError suggestedAction(String suggestedAction)
@Nullable public String getSuggestedAction()
public void setSuggestedAction(String suggestedAction)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.