public enum ProgramNameSensitivity extends Enum<ProgramNameSensitivity>
| Modifier and Type | Class and Description |
|---|---|
static class |
ProgramNameSensitivity.Adapter |
| Enum Constant and Description |
|---|
BALANCED |
COARSE |
ENUM_UNKNOWN |
EXACT |
STRICT |
| Modifier and Type | Method and Description |
|---|---|
static ProgramNameSensitivity |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static ProgramNameSensitivity |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static ProgramNameSensitivity[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ProgramNameSensitivity COARSE
public static final ProgramNameSensitivity BALANCED
public static final ProgramNameSensitivity STRICT
public static final ProgramNameSensitivity EXACT
public static final ProgramNameSensitivity ENUM_UNKNOWN
public static ProgramNameSensitivity[] values()
for (ProgramNameSensitivity c : ProgramNameSensitivity.values()) System.out.println(c);
public static ProgramNameSensitivity valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<ProgramNameSensitivity>public static ProgramNameSensitivity fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.