@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class RecaptchaRequiredError extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_COMMON_CAUSES |
static String |
SERIALIZED_NAME_DISPLAY_MESSAGE |
static String |
SERIALIZED_NAME_ERROR_CODE |
static String |
SERIALIZED_NAME_ERROR_TYPE |
static String |
SERIALIZED_NAME_HTTP_CODE |
static String |
SERIALIZED_NAME_LINK_USER_EXPERIENCE |
static String |
SERIALIZED_NAME_TROUBLESHOOTING_STEPS |
| Constructor and Description |
|---|
RecaptchaRequiredError() |
| Modifier and Type | Method and Description |
|---|---|
RecaptchaRequiredError |
commonCauses(String commonCauses) |
RecaptchaRequiredError |
displayMessage(String displayMessage) |
boolean |
equals(Object o) |
RecaptchaRequiredError |
errorCode(String errorCode) |
RecaptchaRequiredError |
errorType(String errorType) |
String |
getCommonCauses()
Plaid's fraud system detects abusive traffic and considers a variety of parameters throughout Item creation requests.
|
String |
getDisplayMessage()
Get displayMessage
|
String |
getErrorCode()
RECAPTCHA_REQUIRED
|
String |
getErrorType()
RECAPTCHA_ERROR
|
String |
getHttpCode()
400
|
String |
getLinkUserExperience()
Your user will be prompted to solve a Google reCAPTCHA challenge in the Link Recaptcha pane.
|
String |
getTroubleshootingSteps()
Link will automatically guide your user through reCAPTCHA verification.
|
int |
hashCode() |
RecaptchaRequiredError |
httpCode(String httpCode) |
RecaptchaRequiredError |
linkUserExperience(String linkUserExperience) |
void |
setCommonCauses(String commonCauses) |
void |
setDisplayMessage(String displayMessage) |
void |
setErrorCode(String errorCode) |
void |
setErrorType(String errorType) |
void |
setHttpCode(String httpCode) |
void |
setLinkUserExperience(String linkUserExperience) |
void |
setTroubleshootingSteps(String troubleshootingSteps) |
String |
toString() |
RecaptchaRequiredError |
troubleshootingSteps(String troubleshootingSteps) |
public static final String SERIALIZED_NAME_ERROR_TYPE
public static final String SERIALIZED_NAME_ERROR_CODE
public static final String SERIALIZED_NAME_DISPLAY_MESSAGE
public static final String SERIALIZED_NAME_HTTP_CODE
public static final String SERIALIZED_NAME_LINK_USER_EXPERIENCE
public static final String SERIALIZED_NAME_COMMON_CAUSES
public static final String SERIALIZED_NAME_TROUBLESHOOTING_STEPS
public RecaptchaRequiredError errorType(String errorType)
public String getErrorType()
public void setErrorType(String errorType)
public RecaptchaRequiredError errorCode(String errorCode)
public String getErrorCode()
public void setErrorCode(String errorCode)
public RecaptchaRequiredError displayMessage(String displayMessage)
public String getDisplayMessage()
public void setDisplayMessage(String displayMessage)
public RecaptchaRequiredError httpCode(String httpCode)
public String getHttpCode()
public void setHttpCode(String httpCode)
public RecaptchaRequiredError linkUserExperience(String linkUserExperience)
public String getLinkUserExperience()
public void setLinkUserExperience(String linkUserExperience)
public RecaptchaRequiredError commonCauses(String commonCauses)
public String getCommonCauses()
public void setCommonCauses(String commonCauses)
public RecaptchaRequiredError troubleshootingSteps(String troubleshootingSteps)
public String getTroubleshootingSteps()
public void setTroubleshootingSteps(String troubleshootingSteps)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.