public enum RiskCheckBehaviorFraudRingDetectedLabel extends Enum<RiskCheckBehaviorFraudRingDetectedLabel>
| Modifier and Type | Class and Description |
|---|---|
static class |
RiskCheckBehaviorFraudRingDetectedLabel.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
NO |
NO_DATA |
YES |
| Modifier and Type | Method and Description |
|---|---|
static RiskCheckBehaviorFraudRingDetectedLabel |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static RiskCheckBehaviorFraudRingDetectedLabel |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static RiskCheckBehaviorFraudRingDetectedLabel[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final RiskCheckBehaviorFraudRingDetectedLabel YES
public static final RiskCheckBehaviorFraudRingDetectedLabel NO
public static final RiskCheckBehaviorFraudRingDetectedLabel NO_DATA
public static final RiskCheckBehaviorFraudRingDetectedLabel ENUM_UNKNOWN
public static RiskCheckBehaviorFraudRingDetectedLabel[] values()
for (RiskCheckBehaviorFraudRingDetectedLabel c : RiskCheckBehaviorFraudRingDetectedLabel.values()) System.out.println(c);
public static RiskCheckBehaviorFraudRingDetectedLabel valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<RiskCheckBehaviorFraudRingDetectedLabel>public static RiskCheckBehaviorFraudRingDetectedLabel fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.