public enum SandboxBankIncomeWebhookFireRequestWebhookCode extends Enum<SandboxBankIncomeWebhookFireRequestWebhookCode>
| Modifier and Type | Class and Description |
|---|---|
static class |
SandboxBankIncomeWebhookFireRequestWebhookCode.Adapter |
| Enum Constant and Description |
|---|
COMPLETE |
ENUM_UNKNOWN |
UPDATE |
| Modifier and Type | Method and Description |
|---|---|
static SandboxBankIncomeWebhookFireRequestWebhookCode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static SandboxBankIncomeWebhookFireRequestWebhookCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static SandboxBankIncomeWebhookFireRequestWebhookCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final SandboxBankIncomeWebhookFireRequestWebhookCode UPDATE
public static final SandboxBankIncomeWebhookFireRequestWebhookCode COMPLETE
public static final SandboxBankIncomeWebhookFireRequestWebhookCode ENUM_UNKNOWN
public static SandboxBankIncomeWebhookFireRequestWebhookCode[] values()
for (SandboxBankIncomeWebhookFireRequestWebhookCode c : SandboxBankIncomeWebhookFireRequestWebhookCode.values()) System.out.println(c);
public static SandboxBankIncomeWebhookFireRequestWebhookCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<SandboxBankIncomeWebhookFireRequestWebhookCode>public static SandboxBankIncomeWebhookFireRequestWebhookCode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.