public enum Strategy extends Enum<Strategy>
| Modifier and Type | Class and Description |
|---|---|
static class |
Strategy.Adapter |
| Enum Constant and Description |
|---|
CUSTOM |
ENUM_UNKNOWN |
INCOMPLETE |
INFER |
RESET |
| Modifier and Type | Method and Description |
|---|---|
static Strategy |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static Strategy |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Strategy[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Strategy RESET
public static final Strategy INCOMPLETE
public static final Strategy INFER
public static final Strategy CUSTOM
public static final Strategy ENUM_UNKNOWN
public static Strategy[] values()
for (Strategy c : Strategy.values()) System.out.println(c);
public static Strategy valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
Copyright © 2017–2023 Plaid Inc.. All rights reserved.