@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class StudentLoanRepaymentModel extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_NON_REPAYMENT_MONTHS |
static String |
SERIALIZED_NAME_REPAYMENT_MONTHS |
static String |
SERIALIZED_NAME_TYPE |
| Constructor and Description |
|---|
StudentLoanRepaymentModel() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object o) |
Double |
getNonRepaymentMonths()
Configures the number of months before repayment starts.
|
Double |
getRepaymentMonths()
Configures the number of months of repayments before the loan is paid off.
|
String |
getType()
The only currently supported value for this field is `standard`.
|
int |
hashCode() |
StudentLoanRepaymentModel |
nonRepaymentMonths(Double nonRepaymentMonths) |
StudentLoanRepaymentModel |
repaymentMonths(Double repaymentMonths) |
void |
setNonRepaymentMonths(Double nonRepaymentMonths) |
void |
setRepaymentMonths(Double repaymentMonths) |
void |
setType(String type) |
String |
toString() |
StudentLoanRepaymentModel |
type(String type) |
public static final String SERIALIZED_NAME_TYPE
public static final String SERIALIZED_NAME_NON_REPAYMENT_MONTHS
public static final String SERIALIZED_NAME_REPAYMENT_MONTHS
public StudentLoanRepaymentModel type(String type)
public String getType()
public void setType(String type)
public StudentLoanRepaymentModel nonRepaymentMonths(Double nonRepaymentMonths)
public Double getNonRepaymentMonths()
public void setNonRepaymentMonths(Double nonRepaymentMonths)
public StudentLoanRepaymentModel repaymentMonths(Double repaymentMonths)
public Double getRepaymentMonths()
public void setRepaymentMonths(Double repaymentMonths)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.