public enum SweepTrigger extends Enum<SweepTrigger>
| Modifier and Type | Class and Description |
|---|---|
static class |
SweepTrigger.Adapter |
| Enum Constant and Description |
|---|
AUTOMATIC_AGGREGATE |
BALANCE_THRESHOLD |
ENUM_UNKNOWN |
INCOMING |
MANUAL |
| Modifier and Type | Method and Description |
|---|---|
static SweepTrigger |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static SweepTrigger |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static SweepTrigger[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final SweepTrigger MANUAL
public static final SweepTrigger INCOMING
public static final SweepTrigger BALANCE_THRESHOLD
public static final SweepTrigger AUTOMATIC_AGGREGATE
public static final SweepTrigger ENUM_UNKNOWN
public static SweepTrigger[] values()
for (SweepTrigger c : SweepTrigger.values()) System.out.println(c);
public static SweepTrigger valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<SweepTrigger>public static SweepTrigger fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.