@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class TransactionBase extends Object
| Modifier and Type | Class and Description |
|---|---|
static class |
TransactionBase.TransactionTypeEnum
Please use the `payment_channel` field, `transaction_type` will be deprecated in the future.
|
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCOUNT_ID |
static String |
SERIALIZED_NAME_ACCOUNT_OWNER |
static String |
SERIALIZED_NAME_AMOUNT |
static String |
SERIALIZED_NAME_CATEGORY |
static String |
SERIALIZED_NAME_CATEGORY_ID |
static String |
SERIALIZED_NAME_CHECK_NUMBER |
static String |
SERIALIZED_NAME_DATE |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_LOCATION |
static String |
SERIALIZED_NAME_LOGO_URL |
static String |
SERIALIZED_NAME_MERCHANT_NAME |
static String |
SERIALIZED_NAME_NAME |
static String |
SERIALIZED_NAME_ORIGINAL_DESCRIPTION |
static String |
SERIALIZED_NAME_PAYMENT_META |
static String |
SERIALIZED_NAME_PENDING |
static String |
SERIALIZED_NAME_PENDING_TRANSACTION_ID |
static String |
SERIALIZED_NAME_TRANSACTION_ID |
static String |
SERIALIZED_NAME_TRANSACTION_TYPE |
static String |
SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE |
static String |
SERIALIZED_NAME_WEBSITE |
| Constructor and Description |
|---|
TransactionBase() |
| Modifier and Type | Method and Description |
|---|---|
TransactionBase |
accountId(String accountId) |
TransactionBase |
accountOwner(String accountOwner) |
TransactionBase |
addCategoryItem(String categoryItem) |
TransactionBase |
amount(Double amount) |
TransactionBase |
category(List<String> category) |
TransactionBase |
categoryId(String categoryId) |
TransactionBase |
checkNumber(String checkNumber) |
TransactionBase |
date(LocalDate date) |
boolean |
equals(Object o) |
String |
getAccountId()
The ID of the account in which this transaction occurred.
|
String |
getAccountOwner()
The name of the account owner.
|
Double |
getAmount()
The settled value of the transaction, denominated in the transactions's currency, as stated in `iso_currency_code` or `unofficial_currency_code`.
|
List<String> |
getCategory()
A hierarchical array of the categories to which this transaction belongs.
|
String |
getCategoryId()
The ID of the category to which this transaction belongs.
|
String |
getCheckNumber()
The check number of the transaction.
|
LocalDate |
getDate()
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted.
|
String |
getIsoCurrencyCode()
The ISO-4217 currency code of the transaction.
|
Location |
getLocation()
Get location
|
String |
getLogoUrl()
The URL of a logo associated with this transaction, if available.
|
String |
getMerchantName()
The merchant name, as enriched by Plaid from the `name` field.
|
String |
getName()
The merchant name or transaction description.
|
String |
getOriginalDescription()
The string returned by the financial institution to describe the transaction.
|
PaymentMeta |
getPaymentMeta()
Get paymentMeta
|
Boolean |
getPending()
When `true`, identifies the transaction as pending or unsettled.
|
String |
getPendingTransactionId()
The ID of a posted transaction's associated pending transaction, where applicable.
|
String |
getTransactionId()
The unique ID of the transaction.
|
TransactionBase.TransactionTypeEnum |
getTransactionType()
Please use the `payment_channel` field, `transaction_type` will be deprecated in the future.
|
String |
getUnofficialCurrencyCode()
The unofficial currency code associated with the transaction.
|
String |
getWebsite()
The website associated with this transaction, if available.
|
int |
hashCode() |
TransactionBase |
isoCurrencyCode(String isoCurrencyCode) |
TransactionBase |
location(Location location) |
TransactionBase |
logoUrl(String logoUrl) |
TransactionBase |
merchantName(String merchantName) |
TransactionBase |
name(String name) |
TransactionBase |
originalDescription(String originalDescription) |
TransactionBase |
paymentMeta(PaymentMeta paymentMeta) |
TransactionBase |
pending(Boolean pending) |
TransactionBase |
pendingTransactionId(String pendingTransactionId) |
void |
setAccountId(String accountId) |
void |
setAccountOwner(String accountOwner) |
void |
setAmount(Double amount) |
void |
setCategory(List<String> category) |
void |
setCategoryId(String categoryId) |
void |
setCheckNumber(String checkNumber) |
void |
setDate(LocalDate date) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setLocation(Location location) |
void |
setLogoUrl(String logoUrl) |
void |
setMerchantName(String merchantName) |
void |
setName(String name) |
void |
setOriginalDescription(String originalDescription) |
void |
setPaymentMeta(PaymentMeta paymentMeta) |
void |
setPending(Boolean pending) |
void |
setPendingTransactionId(String pendingTransactionId) |
void |
setTransactionId(String transactionId) |
void |
setTransactionType(TransactionBase.TransactionTypeEnum transactionType) |
void |
setUnofficialCurrencyCode(String unofficialCurrencyCode) |
void |
setWebsite(String website) |
String |
toString() |
TransactionBase |
transactionId(String transactionId) |
TransactionBase |
transactionType(TransactionBase.TransactionTypeEnum transactionType) |
TransactionBase |
unofficialCurrencyCode(String unofficialCurrencyCode) |
TransactionBase |
website(String website) |
public static final String SERIALIZED_NAME_ACCOUNT_ID
public static final String SERIALIZED_NAME_AMOUNT
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_UNOFFICIAL_CURRENCY_CODE
public static final String SERIALIZED_NAME_CATEGORY
public static final String SERIALIZED_NAME_CATEGORY_ID
public static final String SERIALIZED_NAME_CHECK_NUMBER
public static final String SERIALIZED_NAME_DATE
public static final String SERIALIZED_NAME_LOCATION
public static final String SERIALIZED_NAME_NAME
public static final String SERIALIZED_NAME_MERCHANT_NAME
public static final String SERIALIZED_NAME_ORIGINAL_DESCRIPTION
public static final String SERIALIZED_NAME_PAYMENT_META
public static final String SERIALIZED_NAME_PENDING
public static final String SERIALIZED_NAME_PENDING_TRANSACTION_ID
public static final String SERIALIZED_NAME_ACCOUNT_OWNER
public static final String SERIALIZED_NAME_TRANSACTION_ID
public static final String SERIALIZED_NAME_TRANSACTION_TYPE
public static final String SERIALIZED_NAME_LOGO_URL
public static final String SERIALIZED_NAME_WEBSITE
public TransactionBase accountId(String accountId)
public String getAccountId()
public void setAccountId(String accountId)
public TransactionBase amount(Double amount)
public Double getAmount()
public void setAmount(Double amount)
public TransactionBase isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public TransactionBase unofficialCurrencyCode(String unofficialCurrencyCode)
@Nullable public String getUnofficialCurrencyCode()
public void setUnofficialCurrencyCode(String unofficialCurrencyCode)
public TransactionBase category(List<String> category)
public TransactionBase addCategoryItem(String categoryItem)
@Nullable public List<String> getCategory()
public TransactionBase categoryId(String categoryId)
@Nullable public String getCategoryId()
public void setCategoryId(String categoryId)
public TransactionBase checkNumber(String checkNumber)
@Nullable public String getCheckNumber()
public void setCheckNumber(String checkNumber)
public TransactionBase date(LocalDate date)
public LocalDate getDate()
public void setDate(LocalDate date)
public TransactionBase location(Location location)
public void setLocation(Location location)
public TransactionBase name(String name)
@Nullable public String getName()
public void setName(String name)
public TransactionBase merchantName(String merchantName)
@Nullable public String getMerchantName()
public void setMerchantName(String merchantName)
public TransactionBase originalDescription(String originalDescription)
@Nullable public String getOriginalDescription()
public void setOriginalDescription(String originalDescription)
public TransactionBase paymentMeta(PaymentMeta paymentMeta)
@Nullable public PaymentMeta getPaymentMeta()
public void setPaymentMeta(PaymentMeta paymentMeta)
public TransactionBase pending(Boolean pending)
public Boolean getPending()
public void setPending(Boolean pending)
public TransactionBase pendingTransactionId(String pendingTransactionId)
@Nullable public String getPendingTransactionId()
public void setPendingTransactionId(String pendingTransactionId)
public TransactionBase accountOwner(String accountOwner)
@Nullable public String getAccountOwner()
public void setAccountOwner(String accountOwner)
public TransactionBase transactionId(String transactionId)
public String getTransactionId()
public void setTransactionId(String transactionId)
public TransactionBase transactionType(TransactionBase.TransactionTypeEnum transactionType)
@Nullable public TransactionBase.TransactionTypeEnum getTransactionType()
public void setTransactionType(TransactionBase.TransactionTypeEnum transactionType)
public TransactionBase logoUrl(String logoUrl)
@Nullable public String getLogoUrl()
public void setLogoUrl(String logoUrl)
public TransactionBase website(String website)
@Nullable public String getWebsite()
public void setWebsite(String website)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.