public enum TransactionsRuleField extends Enum<TransactionsRuleField>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransactionsRuleField.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
NAME |
TRANSACTION_ID |
| Modifier and Type | Method and Description |
|---|---|
static TransactionsRuleField |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransactionsRuleField |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransactionsRuleField[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransactionsRuleField TRANSACTION_ID
public static final TransactionsRuleField NAME
public static final TransactionsRuleField ENUM_UNKNOWN
public static TransactionsRuleField[] values()
for (TransactionsRuleField c : TransactionsRuleField.values()) System.out.println(c);
public static TransactionsRuleField valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransactionsRuleField>public static TransactionsRuleField fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.