public enum TransferACHNetwork extends Enum<TransferACHNetwork>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransferACHNetwork.Adapter |
| Enum Constant and Description |
|---|
ACH |
ENUM_UNKNOWN |
SAME_DAY_ACH |
| Modifier and Type | Method and Description |
|---|---|
static TransferACHNetwork |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransferACHNetwork |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransferACHNetwork[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransferACHNetwork ACH
public static final TransferACHNetwork SAME_DAY_ACH
public static final TransferACHNetwork ENUM_UNKNOWN
public static TransferACHNetwork[] values()
for (TransferACHNetwork c : TransferACHNetwork.values()) System.out.println(c);
public static TransferACHNetwork valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransferACHNetwork>public static TransferACHNetwork fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.