@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class TransferAuthorizationCreateRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ACCESS_TOKEN |
static String |
SERIALIZED_NAME_ACCOUNT_ID |
static String |
SERIALIZED_NAME_ACH_CLASS |
static String |
SERIALIZED_NAME_AMOUNT |
static String |
SERIALIZED_NAME_BEACON_SESSION_ID |
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_CREDIT_FUNDS_SOURCE |
static String |
SERIALIZED_NAME_DEVICE |
static String |
SERIALIZED_NAME_FUNDING_ACCOUNT_ID |
static String |
SERIALIZED_NAME_IDEMPOTENCY_KEY |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_NETWORK |
static String |
SERIALIZED_NAME_ORIGINATION_ACCOUNT_ID |
static String |
SERIALIZED_NAME_ORIGINATOR_CLIENT_ID |
static String |
SERIALIZED_NAME_PAYMENT_PROFILE_TOKEN |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_TEST_CLOCK_ID |
static String |
SERIALIZED_NAME_TYPE |
static String |
SERIALIZED_NAME_USER |
static String |
SERIALIZED_NAME_USER_PRESENT |
static String |
SERIALIZED_NAME_WITH_GUARANTEE |
| Constructor and Description |
|---|
TransferAuthorizationCreateRequest() |
| Modifier and Type | Method and Description |
|---|---|
TransferAuthorizationCreateRequest |
accessToken(String accessToken) |
TransferAuthorizationCreateRequest |
accountId(String accountId) |
TransferAuthorizationCreateRequest |
achClass(ACHClass achClass) |
TransferAuthorizationCreateRequest |
amount(String amount) |
TransferAuthorizationCreateRequest |
beaconSessionId(String beaconSessionId) |
TransferAuthorizationCreateRequest |
clientId(String clientId) |
TransferAuthorizationCreateRequest |
creditFundsSource(TransferCreditFundsSource creditFundsSource) |
TransferAuthorizationCreateRequest |
device(TransferAuthorizationDevice device) |
boolean |
equals(Object o) |
TransferAuthorizationCreateRequest |
fundingAccountId(String fundingAccountId) |
String |
getAccessToken()
The Plaid `access_token` for the account that will be debited or credited.
|
String |
getAccountId()
The Plaid `account_id` corresponding to the end-user account that will be debited or credited.
|
ACHClass |
getAchClass()
Get achClass
|
String |
getAmount()
The amount of the transfer (decimal string with two digits of precision e.g.
|
String |
getBeaconSessionId()
The unique identifier returned by Plaid's [beacon](https://plaid.com/docs/transfer/guarantee/#using-a-beacon) when it is run on your webpage.
|
String |
getClientId()
Your Plaid API `client_id`.
|
TransferCreditFundsSource |
getCreditFundsSource()
Get creditFundsSource
|
TransferAuthorizationDevice |
getDevice()
Get device
|
String |
getFundingAccountId()
The id of the funding account to use, available in the Plaid Dashboard.
|
String |
getIdempotencyKey()
A random key provided by the client, per unique authorization, which expires after 48 hours.
|
String |
getIsoCurrencyCode()
The currency of the transfer amount.
|
TransferNetwork |
getNetwork()
Get network
|
String |
getOriginationAccountId()
Plaid's unique identifier for the origination account for this authorization.
|
String |
getOriginatorClientId()
The Plaid client ID that is the originator of this transfer.
|
String |
getPaymentProfileToken()
The payment profile token associated with the Payment Profile that will be debited or credited.
|
String |
getSecret()
Your Plaid API `secret`.
|
String |
getTestClockId()
Plaid’s unique identifier for a test clock.
|
TransferType |
getType()
Get type
|
TransferAuthorizationUserInRequest |
getUser()
Get user
|
Boolean |
getUserPresent()
If the end user is initiating the specific transfer themselves via an interactive UI, this should be `true`; for automatic recurring payments where the end user is not actually initiating each individual transfer, it should be `false`.
|
Boolean |
getWithGuarantee()
If set to `false`, Plaid will not offer a `guarantee_decision` for this request (Guarantee customers only).
|
int |
hashCode() |
TransferAuthorizationCreateRequest |
idempotencyKey(String idempotencyKey) |
TransferAuthorizationCreateRequest |
isoCurrencyCode(String isoCurrencyCode) |
TransferAuthorizationCreateRequest |
network(TransferNetwork network) |
TransferAuthorizationCreateRequest |
originationAccountId(String originationAccountId) |
TransferAuthorizationCreateRequest |
originatorClientId(String originatorClientId) |
TransferAuthorizationCreateRequest |
paymentProfileToken(String paymentProfileToken) |
TransferAuthorizationCreateRequest |
secret(String secret) |
void |
setAccessToken(String accessToken) |
void |
setAccountId(String accountId) |
void |
setAchClass(ACHClass achClass) |
void |
setAmount(String amount) |
void |
setBeaconSessionId(String beaconSessionId) |
void |
setClientId(String clientId) |
void |
setCreditFundsSource(TransferCreditFundsSource creditFundsSource) |
void |
setDevice(TransferAuthorizationDevice device) |
void |
setFundingAccountId(String fundingAccountId) |
void |
setIdempotencyKey(String idempotencyKey) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setNetwork(TransferNetwork network) |
void |
setOriginationAccountId(String originationAccountId) |
void |
setOriginatorClientId(String originatorClientId) |
void |
setPaymentProfileToken(String paymentProfileToken) |
void |
setSecret(String secret) |
void |
setTestClockId(String testClockId) |
void |
setType(TransferType type) |
void |
setUser(TransferAuthorizationUserInRequest user) |
void |
setUserPresent(Boolean userPresent) |
void |
setWithGuarantee(Boolean withGuarantee) |
TransferAuthorizationCreateRequest |
testClockId(String testClockId) |
String |
toString() |
TransferAuthorizationCreateRequest |
type(TransferType type) |
TransferAuthorizationCreateRequest |
user(TransferAuthorizationUserInRequest user) |
TransferAuthorizationCreateRequest |
userPresent(Boolean userPresent) |
TransferAuthorizationCreateRequest |
withGuarantee(Boolean withGuarantee) |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_ACCESS_TOKEN
public static final String SERIALIZED_NAME_ACCOUNT_ID
public static final String SERIALIZED_NAME_FUNDING_ACCOUNT_ID
public static final String SERIALIZED_NAME_PAYMENT_PROFILE_TOKEN
public static final String SERIALIZED_NAME_TYPE
public static final String SERIALIZED_NAME_NETWORK
public static final String SERIALIZED_NAME_AMOUNT
public static final String SERIALIZED_NAME_ACH_CLASS
public static final String SERIALIZED_NAME_USER
public static final String SERIALIZED_NAME_DEVICE
public static final String SERIALIZED_NAME_ORIGINATION_ACCOUNT_ID
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_IDEMPOTENCY_KEY
public static final String SERIALIZED_NAME_USER_PRESENT
public static final String SERIALIZED_NAME_WITH_GUARANTEE
public static final String SERIALIZED_NAME_BEACON_SESSION_ID
public static final String SERIALIZED_NAME_ORIGINATOR_CLIENT_ID
public static final String SERIALIZED_NAME_CREDIT_FUNDS_SOURCE
public static final String SERIALIZED_NAME_TEST_CLOCK_ID
public TransferAuthorizationCreateRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public TransferAuthorizationCreateRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public TransferAuthorizationCreateRequest accessToken(String accessToken)
@Nullable public String getAccessToken()
public void setAccessToken(String accessToken)
public TransferAuthorizationCreateRequest accountId(String accountId)
@Nullable public String getAccountId()
public void setAccountId(String accountId)
public TransferAuthorizationCreateRequest fundingAccountId(String fundingAccountId)
@Nullable public String getFundingAccountId()
public void setFundingAccountId(String fundingAccountId)
public TransferAuthorizationCreateRequest paymentProfileToken(String paymentProfileToken)
@Nullable public String getPaymentProfileToken()
public void setPaymentProfileToken(String paymentProfileToken)
public TransferAuthorizationCreateRequest type(TransferType type)
public TransferType getType()
public void setType(TransferType type)
public TransferAuthorizationCreateRequest network(TransferNetwork network)
public TransferNetwork getNetwork()
public void setNetwork(TransferNetwork network)
public TransferAuthorizationCreateRequest amount(String amount)
public String getAmount()
public void setAmount(String amount)
public TransferAuthorizationCreateRequest achClass(ACHClass achClass)
public void setAchClass(ACHClass achClass)
public TransferAuthorizationCreateRequest user(TransferAuthorizationUserInRequest user)
public TransferAuthorizationUserInRequest getUser()
public void setUser(TransferAuthorizationUserInRequest user)
public TransferAuthorizationCreateRequest device(TransferAuthorizationDevice device)
@Nullable public TransferAuthorizationDevice getDevice()
public void setDevice(TransferAuthorizationDevice device)
public TransferAuthorizationCreateRequest originationAccountId(String originationAccountId)
@Nullable public String getOriginationAccountId()
public void setOriginationAccountId(String originationAccountId)
public TransferAuthorizationCreateRequest isoCurrencyCode(String isoCurrencyCode)
@Nullable public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public TransferAuthorizationCreateRequest idempotencyKey(String idempotencyKey)
@Nullable public String getIdempotencyKey()
public void setIdempotencyKey(String idempotencyKey)
public TransferAuthorizationCreateRequest userPresent(Boolean userPresent)
@Nullable public Boolean getUserPresent()
public void setUserPresent(Boolean userPresent)
public TransferAuthorizationCreateRequest withGuarantee(Boolean withGuarantee)
@Nullable public Boolean getWithGuarantee()
public void setWithGuarantee(Boolean withGuarantee)
public TransferAuthorizationCreateRequest beaconSessionId(String beaconSessionId)
@Nullable public String getBeaconSessionId()
public void setBeaconSessionId(String beaconSessionId)
public TransferAuthorizationCreateRequest originatorClientId(String originatorClientId)
@Nullable public String getOriginatorClientId()
public void setOriginatorClientId(String originatorClientId)
public TransferAuthorizationCreateRequest creditFundsSource(TransferCreditFundsSource creditFundsSource)
@Nullable public TransferCreditFundsSource getCreditFundsSource()
public void setCreditFundsSource(TransferCreditFundsSource creditFundsSource)
public TransferAuthorizationCreateRequest testClockId(String testClockId)
@Nullable public String getTestClockId()
public void setTestClockId(String testClockId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.