@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class TransferBalance extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AVAILABLE |
static String |
SERIALIZED_NAME_CURRENT |
static String |
SERIALIZED_NAME_TYPE |
| Constructor and Description |
|---|
TransferBalance() |
| Modifier and Type | Method and Description |
|---|---|
TransferBalance |
available(String available) |
TransferBalance |
current(String current) |
boolean |
equals(Object o) |
String |
getAvailable()
The amount of this balance available for use (decimal string with two digits of precision e.g.
|
String |
getCurrent()
The available balance, plus amount of pending funds that in processing (decimal string with two digits of precision e.g.
|
TransferBalanceType |
getType()
Get type
|
int |
hashCode() |
void |
setAvailable(String available) |
void |
setCurrent(String current) |
void |
setType(TransferBalanceType type) |
String |
toString() |
TransferBalance |
type(TransferBalanceType type) |
public static final String SERIALIZED_NAME_AVAILABLE
public static final String SERIALIZED_NAME_CURRENT
public static final String SERIALIZED_NAME_TYPE
public TransferBalance available(String available)
public String getAvailable()
public void setAvailable(String available)
public TransferBalance current(String current)
@Nullable public String getCurrent()
public void setCurrent(String current)
public TransferBalance type(TransferBalanceType type)
public TransferBalanceType getType()
public void setType(TransferBalanceType type)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.