public enum TransferCreditFundsSource extends Enum<TransferCreditFundsSource>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransferCreditFundsSource.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
NULL |
PREFUNDED_ACH_CREDITS |
PREFUNDED_RTP_CREDITS |
SWEEP |
| Modifier and Type | Method and Description |
|---|---|
static TransferCreditFundsSource |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransferCreditFundsSource |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransferCreditFundsSource[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransferCreditFundsSource SWEEP
public static final TransferCreditFundsSource PREFUNDED_RTP_CREDITS
public static final TransferCreditFundsSource PREFUNDED_ACH_CREDITS
public static final TransferCreditFundsSource NULL
public static final TransferCreditFundsSource ENUM_UNKNOWN
public static TransferCreditFundsSource[] values()
for (TransferCreditFundsSource c : TransferCreditFundsSource.values()) System.out.println(c);
public static TransferCreditFundsSource valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransferCreditFundsSource>public static TransferCreditFundsSource fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.