@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class TransferDevice extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_IP_ADDRESS |
static String |
SERIALIZED_NAME_USER_AGENT |
| Constructor and Description |
|---|
TransferDevice() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object o) |
String |
getIpAddress()
The IP address of the device being used to initiate the authorization.
|
String |
getUserAgent()
The user agent of the device being used to initiate the authorization.
|
int |
hashCode() |
TransferDevice |
ipAddress(String ipAddress) |
void |
setIpAddress(String ipAddress) |
void |
setUserAgent(String userAgent) |
String |
toString() |
TransferDevice |
userAgent(String userAgent) |
public static final String SERIALIZED_NAME_IP_ADDRESS
public static final String SERIALIZED_NAME_USER_AGENT
public TransferDevice ipAddress(String ipAddress)
public String getIpAddress()
public void setIpAddress(String ipAddress)
public TransferDevice userAgent(String userAgent)
public String getUserAgent()
public void setUserAgent(String userAgent)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.