public enum TransferIntentAuthorizationDecision extends Enum<TransferIntentAuthorizationDecision>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransferIntentAuthorizationDecision.Adapter |
| Enum Constant and Description |
|---|
APPROVED |
DECLINED |
ENUM_UNKNOWN |
| Modifier and Type | Method and Description |
|---|---|
static TransferIntentAuthorizationDecision |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransferIntentAuthorizationDecision |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransferIntentAuthorizationDecision[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransferIntentAuthorizationDecision APPROVED
public static final TransferIntentAuthorizationDecision DECLINED
public static final TransferIntentAuthorizationDecision ENUM_UNKNOWN
public static TransferIntentAuthorizationDecision[] values()
for (TransferIntentAuthorizationDecision c : TransferIntentAuthorizationDecision.values()) System.out.println(c);
public static TransferIntentAuthorizationDecision valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransferIntentAuthorizationDecision>public static TransferIntentAuthorizationDecision fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.