public enum TransferIntentCreateMode extends Enum<TransferIntentCreateMode>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransferIntentCreateMode.Adapter |
| Enum Constant and Description |
|---|
DISBURSEMENT |
ENUM_UNKNOWN |
PAYMENT |
| Modifier and Type | Method and Description |
|---|---|
static TransferIntentCreateMode |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransferIntentCreateMode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransferIntentCreateMode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransferIntentCreateMode PAYMENT
public static final TransferIntentCreateMode DISBURSEMENT
public static final TransferIntentCreateMode ENUM_UNKNOWN
public static TransferIntentCreateMode[] values()
for (TransferIntentCreateMode c : TransferIntentCreateMode.values()) System.out.println(c);
public static TransferIntentCreateMode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransferIntentCreateMode>public static TransferIntentCreateMode fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.