@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class TransferIntentGetFailureReason extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ERROR_CODE |
static String |
SERIALIZED_NAME_ERROR_MESSAGE |
static String |
SERIALIZED_NAME_ERROR_TYPE |
| Constructor and Description |
|---|
TransferIntentGetFailureReason() |
| Modifier and Type | Method and Description |
|---|---|
boolean |
equals(Object o) |
TransferIntentGetFailureReason |
errorCode(String errorCode) |
TransferIntentGetFailureReason |
errorMessage(String errorMessage) |
TransferIntentGetFailureReason |
errorType(String errorType) |
String |
getErrorCode()
A code representing the reason for a failed transfer intent (i.e., an API error or the authorization being declined).
|
String |
getErrorMessage()
A human-readable description of the code associated with a failed transfer intent.
|
String |
getErrorType()
A broad categorization of the error.
|
int |
hashCode() |
void |
setErrorCode(String errorCode) |
void |
setErrorMessage(String errorMessage) |
void |
setErrorType(String errorType) |
String |
toString() |
public static final String SERIALIZED_NAME_ERROR_TYPE
public static final String SERIALIZED_NAME_ERROR_CODE
public static final String SERIALIZED_NAME_ERROR_MESSAGE
public TransferIntentGetFailureReason errorType(String errorType)
@Nullable public String getErrorType()
public void setErrorType(String errorType)
public TransferIntentGetFailureReason errorCode(String errorCode)
@Nullable public String getErrorCode()
public void setErrorCode(String errorCode)
public TransferIntentGetFailureReason errorMessage(String errorMessage)
@Nullable public String getErrorMessage()
public void setErrorMessage(String errorMessage)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.