public enum TransferIntentStatus extends Enum<TransferIntentStatus>
| Modifier and Type | Class and Description |
|---|---|
static class |
TransferIntentStatus.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
FAILED |
PENDING |
SUCCEEDED |
| Modifier and Type | Method and Description |
|---|---|
static TransferIntentStatus |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static TransferIntentStatus |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransferIntentStatus[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final TransferIntentStatus PENDING
public static final TransferIntentStatus SUCCEEDED
public static final TransferIntentStatus FAILED
public static final TransferIntentStatus ENUM_UNKNOWN
public static TransferIntentStatus[] values()
for (TransferIntentStatus c : TransferIntentStatus.values()) System.out.println(c);
public static TransferIntentStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<TransferIntentStatus>public static TransferIntentStatus fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.