@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class TransferLedgerBalance extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AVAILABLE |
static String |
SERIALIZED_NAME_PENDING |
| Constructor and Description |
|---|
TransferLedgerBalance() |
| Modifier and Type | Method and Description |
|---|---|
TransferLedgerBalance |
available(String available) |
boolean |
equals(Object o) |
String |
getAvailable()
The amount of this balance available for use (decimal string with two digits of precision e.g.
|
String |
getPending()
The amount of pending funds that are in processing (decimal string with two digits of precision e.g.
|
int |
hashCode() |
TransferLedgerBalance |
pending(String pending) |
void |
setAvailable(String available) |
void |
setPending(String pending) |
String |
toString() |
public static final String SERIALIZED_NAME_AVAILABLE
public static final String SERIALIZED_NAME_PENDING
public TransferLedgerBalance available(String available)
public String getAvailable()
public void setAvailable(String available)
public TransferLedgerBalance pending(String pending)
public String getPending()
public void setPending(String pending)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.