@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class TransferRecurringListRequest extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_CLIENT_ID |
static String |
SERIALIZED_NAME_COUNT |
static String |
SERIALIZED_NAME_END_TIME |
static String |
SERIALIZED_NAME_FUNDING_ACCOUNT_ID |
static String |
SERIALIZED_NAME_OFFSET |
static String |
SERIALIZED_NAME_SECRET |
static String |
SERIALIZED_NAME_START_TIME |
| Constructor and Description |
|---|
TransferRecurringListRequest() |
| Modifier and Type | Method and Description |
|---|---|
TransferRecurringListRequest |
clientId(String clientId) |
TransferRecurringListRequest |
count(Integer count) |
TransferRecurringListRequest |
endTime(OffsetDateTime endTime) |
boolean |
equals(Object o) |
TransferRecurringListRequest |
fundingAccountId(String fundingAccountId) |
String |
getClientId()
Your Plaid API `client_id`.
|
Integer |
getCount()
The maximum number of recurring transfers to return.
|
OffsetDateTime |
getEndTime()
The end datetime of recurring transfers to list.
|
String |
getFundingAccountId()
Filter recurring transfers to only those with the specified `funding_account_id`.
|
Integer |
getOffset()
The number of recurring transfers to skip before returning results.
|
String |
getSecret()
Your Plaid API `secret`.
|
OffsetDateTime |
getStartTime()
The start datetime of recurring transfers to list.
|
int |
hashCode() |
TransferRecurringListRequest |
offset(Integer offset) |
TransferRecurringListRequest |
secret(String secret) |
void |
setClientId(String clientId) |
void |
setCount(Integer count) |
void |
setEndTime(OffsetDateTime endTime) |
void |
setFundingAccountId(String fundingAccountId) |
void |
setOffset(Integer offset) |
void |
setSecret(String secret) |
void |
setStartTime(OffsetDateTime startTime) |
TransferRecurringListRequest |
startTime(OffsetDateTime startTime) |
String |
toString() |
public static final String SERIALIZED_NAME_CLIENT_ID
public static final String SERIALIZED_NAME_SECRET
public static final String SERIALIZED_NAME_START_TIME
public static final String SERIALIZED_NAME_END_TIME
public static final String SERIALIZED_NAME_COUNT
public static final String SERIALIZED_NAME_OFFSET
public static final String SERIALIZED_NAME_FUNDING_ACCOUNT_ID
public TransferRecurringListRequest clientId(String clientId)
@Nullable public String getClientId()
public void setClientId(String clientId)
public TransferRecurringListRequest secret(String secret)
@Nullable public String getSecret()
public void setSecret(String secret)
public TransferRecurringListRequest startTime(OffsetDateTime startTime)
@Nullable public OffsetDateTime getStartTime()
public void setStartTime(OffsetDateTime startTime)
public TransferRecurringListRequest endTime(OffsetDateTime endTime)
@Nullable public OffsetDateTime getEndTime()
public void setEndTime(OffsetDateTime endTime)
public TransferRecurringListRequest count(Integer count)
@Nullable public Integer getCount()
public void setCount(Integer count)
public TransferRecurringListRequest offset(Integer offset)
@Nullable public Integer getOffset()
public void setOffset(Integer offset)
public TransferRecurringListRequest fundingAccountId(String fundingAccountId)
@Nullable public String getFundingAccountId()
public void setFundingAccountId(String fundingAccountId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.