@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class UserCustomPassword extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_FORCE_ERROR |
static String |
SERIALIZED_NAME_MFA |
static String |
SERIALIZED_NAME_OVERRIDE_ACCOUNTS |
static String |
SERIALIZED_NAME_RECAPTCHA |
static String |
SERIALIZED_NAME_SEED |
static String |
SERIALIZED_NAME_VERSION |
| Constructor and Description |
|---|
UserCustomPassword() |
| Modifier and Type | Method and Description |
|---|---|
UserCustomPassword |
addOverrideAccountsItem(OverrideAccounts overrideAccountsItem) |
boolean |
equals(Object o) |
UserCustomPassword |
forceError(String forceError) |
String |
getForceError()
An error code to force on Item creation.
|
MFA |
getMfa()
Get mfa
|
List<OverrideAccounts> |
getOverrideAccounts()
An array of account overrides to configure the accounts for the Item.
|
String |
getRecaptcha()
You may trigger a reCAPTCHA in Plaid Link in the Sandbox environment by using the recaptcha field.
|
String |
getSeed()
A seed, in the form of a string, that will be used to randomly generate account and transaction data, if this data is not specified using the `override_accounts` argument.
|
String |
getVersion()
The version of the password schema to use, possible values are 1 or 2.
|
int |
hashCode() |
UserCustomPassword |
mfa(MFA mfa) |
UserCustomPassword |
overrideAccounts(List<OverrideAccounts> overrideAccounts) |
UserCustomPassword |
recaptcha(String recaptcha) |
UserCustomPassword |
seed(String seed) |
void |
setForceError(String forceError) |
void |
setMfa(MFA mfa) |
void |
setOverrideAccounts(List<OverrideAccounts> overrideAccounts) |
void |
setRecaptcha(String recaptcha) |
void |
setSeed(String seed) |
void |
setVersion(String version) |
String |
toString() |
UserCustomPassword |
version(String version) |
public static final String SERIALIZED_NAME_VERSION
public static final String SERIALIZED_NAME_SEED
public static final String SERIALIZED_NAME_OVERRIDE_ACCOUNTS
public static final String SERIALIZED_NAME_MFA
public static final String SERIALIZED_NAME_RECAPTCHA
public static final String SERIALIZED_NAME_FORCE_ERROR
public UserCustomPassword version(String version)
@Nullable public String getVersion()
public void setVersion(String version)
public UserCustomPassword seed(String seed)
public String getSeed()
public void setSeed(String seed)
public UserCustomPassword overrideAccounts(List<OverrideAccounts> overrideAccounts)
public UserCustomPassword addOverrideAccountsItem(OverrideAccounts overrideAccountsItem)
public List<OverrideAccounts> getOverrideAccounts()
public void setOverrideAccounts(List<OverrideAccounts> overrideAccounts)
public UserCustomPassword mfa(MFA mfa)
public MFA getMfa()
public void setMfa(MFA mfa)
public UserCustomPassword recaptcha(String recaptcha)
public String getRecaptcha()
public void setRecaptcha(String recaptcha)
public UserCustomPassword forceError(String forceError)
public String getForceError()
public void setForceError(String forceError)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.