public enum WalletPaymentScheme extends Enum<WalletPaymentScheme>
| Modifier and Type | Class and Description |
|---|---|
static class |
WalletPaymentScheme.Adapter |
| Enum Constant and Description |
|---|
ENUM_UNKNOWN |
FASTER_PAYMENTS |
NULL |
SEPA_CREDIT_TRANSFER |
SEPA_CREDIT_TRANSFER_INSTANT |
| Modifier and Type | Method and Description |
|---|---|
static WalletPaymentScheme |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static WalletPaymentScheme |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static WalletPaymentScheme[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final WalletPaymentScheme NULL
public static final WalletPaymentScheme FASTER_PAYMENTS
public static final WalletPaymentScheme SEPA_CREDIT_TRANSFER
public static final WalletPaymentScheme SEPA_CREDIT_TRANSFER_INSTANT
public static final WalletPaymentScheme ENUM_UNKNOWN
public static WalletPaymentScheme[] values()
for (WalletPaymentScheme c : WalletPaymentScheme.values()) System.out.println(c);
public static WalletPaymentScheme valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<WalletPaymentScheme>public static WalletPaymentScheme fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.