public enum WalletStatus extends Enum<WalletStatus>
| Modifier and Type | Class and Description |
|---|---|
static class |
WalletStatus.Adapter |
| Enum Constant and Description |
|---|
ACTIVE |
CLOSED |
ENUM_UNKNOWN |
UNKNOWN |
| Modifier and Type | Method and Description |
|---|---|
static WalletStatus |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static WalletStatus |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static WalletStatus[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final WalletStatus UNKNOWN
public static final WalletStatus ACTIVE
public static final WalletStatus CLOSED
public static final WalletStatus ENUM_UNKNOWN
public static WalletStatus[] values()
for (WalletStatus c : WalletStatus.values()) System.out.println(c);
public static WalletStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<WalletStatus>public static WalletStatus fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.