public static enum Warning.WarningCodeEnum extends Enum<Warning.WarningCodeEnum>
| Modifier and Type | Class and Description |
|---|---|
static class |
Warning.WarningCodeEnum.Adapter |
| Enum Constant and Description |
|---|
INVESTMENTS_UNAVAILABLE |
OWNERS_UNAVAILABLE |
TRANSACTIONS_UNAVAILABLE |
| Modifier and Type | Method and Description |
|---|---|
static Warning.WarningCodeEnum |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static Warning.WarningCodeEnum |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Warning.WarningCodeEnum[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Warning.WarningCodeEnum OWNERS_UNAVAILABLE
public static final Warning.WarningCodeEnum INVESTMENTS_UNAVAILABLE
public static final Warning.WarningCodeEnum TRANSACTIONS_UNAVAILABLE
public static Warning.WarningCodeEnum[] values()
for (Warning.WarningCodeEnum c : Warning.WarningCodeEnum.values()) System.out.println(c);
public static Warning.WarningCodeEnum valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<Warning.WarningCodeEnum>public static Warning.WarningCodeEnum fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.