@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class WatchlistScreeningEntityListResponse extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ENTITY_WATCHLIST_SCREENINGS |
static String |
SERIALIZED_NAME_NEXT_CURSOR |
static String |
SERIALIZED_NAME_REQUEST_ID |
| Constructor and Description |
|---|
WatchlistScreeningEntityListResponse() |
| Modifier and Type | Method and Description |
|---|---|
WatchlistScreeningEntityListResponse |
addEntityWatchlistScreeningsItem(EntityWatchlistScreening entityWatchlistScreeningsItem) |
WatchlistScreeningEntityListResponse |
entityWatchlistScreenings(List<EntityWatchlistScreening> entityWatchlistScreenings) |
boolean |
equals(Object o) |
List<EntityWatchlistScreening> |
getEntityWatchlistScreenings()
List of entity watchlist screening
|
String |
getNextCursor()
An identifier that determines which page of results you receive.
|
String |
getRequestId()
A unique identifier for the request, which can be used for troubleshooting.
|
int |
hashCode() |
WatchlistScreeningEntityListResponse |
nextCursor(String nextCursor) |
WatchlistScreeningEntityListResponse |
requestId(String requestId) |
void |
setEntityWatchlistScreenings(List<EntityWatchlistScreening> entityWatchlistScreenings) |
void |
setNextCursor(String nextCursor) |
void |
setRequestId(String requestId) |
String |
toString() |
public static final String SERIALIZED_NAME_ENTITY_WATCHLIST_SCREENINGS
public static final String SERIALIZED_NAME_NEXT_CURSOR
public static final String SERIALIZED_NAME_REQUEST_ID
public WatchlistScreeningEntityListResponse()
public WatchlistScreeningEntityListResponse entityWatchlistScreenings(List<EntityWatchlistScreening> entityWatchlistScreenings)
public WatchlistScreeningEntityListResponse addEntityWatchlistScreeningsItem(EntityWatchlistScreening entityWatchlistScreeningsItem)
public List<EntityWatchlistScreening> getEntityWatchlistScreenings()
public void setEntityWatchlistScreenings(List<EntityWatchlistScreening> entityWatchlistScreenings)
public WatchlistScreeningEntityListResponse nextCursor(String nextCursor)
@Nullable public String getNextCursor()
public void setNextCursor(String nextCursor)
public WatchlistScreeningEntityListResponse requestId(String requestId)
public String getRequestId()
public void setRequestId(String requestId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.