@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-10-17T22:44:09.100608Z[Etc/UTC]") public class WatchlistScreeningEntityProgramListResponse extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_ENTITY_WATCHLIST_PROGRAMS |
static String |
SERIALIZED_NAME_NEXT_CURSOR |
static String |
SERIALIZED_NAME_REQUEST_ID |
| Constructor and Description |
|---|
WatchlistScreeningEntityProgramListResponse() |
| Modifier and Type | Method and Description |
|---|---|
WatchlistScreeningEntityProgramListResponse |
addEntityWatchlistProgramsItem(EntityWatchlistProgram entityWatchlistProgramsItem) |
WatchlistScreeningEntityProgramListResponse |
entityWatchlistPrograms(List<EntityWatchlistProgram> entityWatchlistPrograms) |
boolean |
equals(Object o) |
List<EntityWatchlistProgram> |
getEntityWatchlistPrograms()
List of entity watchlist screening programs
|
String |
getNextCursor()
An identifier that determines which page of results you receive.
|
String |
getRequestId()
A unique identifier for the request, which can be used for troubleshooting.
|
int |
hashCode() |
WatchlistScreeningEntityProgramListResponse |
nextCursor(String nextCursor) |
WatchlistScreeningEntityProgramListResponse |
requestId(String requestId) |
void |
setEntityWatchlistPrograms(List<EntityWatchlistProgram> entityWatchlistPrograms) |
void |
setNextCursor(String nextCursor) |
void |
setRequestId(String requestId) |
String |
toString() |
public static final String SERIALIZED_NAME_ENTITY_WATCHLIST_PROGRAMS
public static final String SERIALIZED_NAME_NEXT_CURSOR
public static final String SERIALIZED_NAME_REQUEST_ID
public WatchlistScreeningEntityProgramListResponse()
public WatchlistScreeningEntityProgramListResponse entityWatchlistPrograms(List<EntityWatchlistProgram> entityWatchlistPrograms)
public WatchlistScreeningEntityProgramListResponse addEntityWatchlistProgramsItem(EntityWatchlistProgram entityWatchlistProgramsItem)
public List<EntityWatchlistProgram> getEntityWatchlistPrograms()
public void setEntityWatchlistPrograms(List<EntityWatchlistProgram> entityWatchlistPrograms)
public WatchlistScreeningEntityProgramListResponse nextCursor(String nextCursor)
@Nullable public String getNextCursor()
public void setNextCursor(String nextCursor)
public WatchlistScreeningEntityProgramListResponse requestId(String requestId)
public String getRequestId()
public void setRequestId(String requestId)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.