public enum WatchlistScreeningEntityUpdateRequestResettableField extends Enum<WatchlistScreeningEntityUpdateRequestResettableField>
| Modifier and Type | Class and Description |
|---|---|
static class |
WatchlistScreeningEntityUpdateRequestResettableField.Adapter |
| Enum Constant and Description |
|---|
ASSIGNEE |
ENUM_UNKNOWN |
| Modifier and Type | Method and Description |
|---|---|
static WatchlistScreeningEntityUpdateRequestResettableField |
fromValue(String value) |
String |
getValue() |
String |
toString() |
static WatchlistScreeningEntityUpdateRequestResettableField |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static WatchlistScreeningEntityUpdateRequestResettableField[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final WatchlistScreeningEntityUpdateRequestResettableField ASSIGNEE
public static final WatchlistScreeningEntityUpdateRequestResettableField ENUM_UNKNOWN
public static WatchlistScreeningEntityUpdateRequestResettableField[] values()
for (WatchlistScreeningEntityUpdateRequestResettableField c : WatchlistScreeningEntityUpdateRequestResettableField.values()) System.out.println(c);
public static WatchlistScreeningEntityUpdateRequestResettableField valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getValue()
public String toString()
toString in class Enum<WatchlistScreeningEntityUpdateRequestResettableField>public static WatchlistScreeningEntityUpdateRequestResettableField fromValue(String value)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.