| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static BaseReportWarningCode |
BaseReportWarningCode.fromValue(String value) |
BaseReportWarningCode |
BaseReportWarning.getWarningCode()
Get warningCode
|
BaseReportWarningCode |
BaseReportWarningCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static BaseReportWarningCode |
BaseReportWarningCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BaseReportWarningCode[] |
BaseReportWarningCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
void |
BaseReportWarning.setWarningCode(BaseReportWarningCode warningCode) |
BaseReportWarning |
BaseReportWarning.warningCode(BaseReportWarningCode warningCode) |
void |
BaseReportWarningCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
BaseReportWarningCode enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.