| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static CountryCode |
CountryCode.fromValue(String value) |
CountryCode |
CountryCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static CountryCode |
CountryCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static CountryCode[] |
CountryCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
List<CountryCode> |
InstitutionsGetByIdRequest.getCountryCodes()
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
|
List<CountryCode> |
LinkTokenGetMetadataResponse.getCountryCodes()
The `country_codes` specified in the `/link/token/create` call.
|
List<CountryCode> |
Institution.getCountryCodes()
A list of the country codes supported by the institution.
|
List<CountryCode> |
LinkTokenCreateRequest.getCountryCodes()
Specify an array of Plaid-supported country codes using the ISO-3166-1 alpha-2 country code standard.
|
List<CountryCode> |
InstitutionsSearchRequest.getCountryCodes()
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
|
List<CountryCode> |
InstitutionsGetRequest.getCountryCodes()
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
|
| Modifier and Type | Method and Description |
|---|---|
InstitutionsGetByIdRequest |
InstitutionsGetByIdRequest.addCountryCodesItem(CountryCode countryCodesItem) |
LinkTokenGetMetadataResponse |
LinkTokenGetMetadataResponse.addCountryCodesItem(CountryCode countryCodesItem) |
Institution |
Institution.addCountryCodesItem(CountryCode countryCodesItem) |
LinkTokenCreateRequest |
LinkTokenCreateRequest.addCountryCodesItem(CountryCode countryCodesItem) |
InstitutionsSearchRequest |
InstitutionsSearchRequest.addCountryCodesItem(CountryCode countryCodesItem) |
InstitutionsGetRequest |
InstitutionsGetRequest.addCountryCodesItem(CountryCode countryCodesItem) |
void |
CountryCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
CountryCode enumeration) |
| Modifier and Type | Method and Description |
|---|---|
InstitutionsGetByIdRequest |
InstitutionsGetByIdRequest.countryCodes(List<CountryCode> countryCodes) |
LinkTokenGetMetadataResponse |
LinkTokenGetMetadataResponse.countryCodes(List<CountryCode> countryCodes) |
Institution |
Institution.countryCodes(List<CountryCode> countryCodes) |
LinkTokenCreateRequest |
LinkTokenCreateRequest.countryCodes(List<CountryCode> countryCodes) |
InstitutionsSearchRequest |
InstitutionsSearchRequest.countryCodes(List<CountryCode> countryCodes) |
InstitutionsGetRequest |
InstitutionsGetRequest.countryCodes(List<CountryCode> countryCodes) |
void |
InstitutionsGetByIdRequest.setCountryCodes(List<CountryCode> countryCodes) |
void |
LinkTokenGetMetadataResponse.setCountryCodes(List<CountryCode> countryCodes) |
void |
Institution.setCountryCodes(List<CountryCode> countryCodes) |
void |
LinkTokenCreateRequest.setCountryCodes(List<CountryCode> countryCodes) |
void |
InstitutionsSearchRequest.setCountryCodes(List<CountryCode> countryCodes) |
void |
InstitutionsGetRequest.setCountryCodes(List<CountryCode> countryCodes) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.