| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
CreditRelayGetRequest |
CreditRelayGetRequest.clientId(String clientId) |
CreditRelayGetRequest |
CreditRelayGetRequest.relayToken(String relayToken) |
CreditRelayGetRequest |
CreditRelayGetRequest.reportType(ReportType reportType) |
CreditRelayGetRequest |
CreditRelayGetRequest.secret(String secret) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<AssetReportGetResponse> |
PlaidApi.creditRelayGet(CreditRelayGetRequest creditRelayGetRequest)
Retrieve the reports associated with a relay token that was shared with you (beta)
`/credit/relay/get` allows third parties to receive a report that was shared with them, using a `relay_token` that was created by the report owner.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.