| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
CreditRelayPDFGetRequest |
CreditRelayPDFGetRequest.clientId(String clientId) |
CreditRelayPDFGetRequest |
CreditRelayPDFGetRequest.relayToken(String relayToken) |
CreditRelayPDFGetRequest |
CreditRelayPDFGetRequest.reportType(ReportType reportType) |
CreditRelayPDFGetRequest |
CreditRelayPDFGetRequest.secret(String secret) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<okhttp3.ResponseBody> |
PlaidApi.creditRelayPdfGet(CreditRelayPDFGetRequest creditRelayPDFGetRequest)
Retrieve the pdf reports associated with a relay token that was shared with you (beta)
`/credit/relay/pdf/get` allows third parties to receive a pdf report that was shared with them, using a `relay_token` that was created by the report owner.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.