| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static DepositSwitchCreateRequest.CountryCodeEnum |
DepositSwitchCreateRequest.CountryCodeEnum.fromValue(String value) |
DepositSwitchCreateRequest.CountryCodeEnum |
DepositSwitchCreateRequest.getCountryCode()
ISO-3166-1 alpha-2 country code standard.
|
DepositSwitchCreateRequest.CountryCodeEnum |
DepositSwitchCreateRequest.CountryCodeEnum.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static DepositSwitchCreateRequest.CountryCodeEnum |
DepositSwitchCreateRequest.CountryCodeEnum.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DepositSwitchCreateRequest.CountryCodeEnum[] |
DepositSwitchCreateRequest.CountryCodeEnum.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
DepositSwitchCreateRequest |
DepositSwitchCreateRequest.countryCode(DepositSwitchCreateRequest.CountryCodeEnum countryCode) |
void |
DepositSwitchCreateRequest.setCountryCode(DepositSwitchCreateRequest.CountryCodeEnum countryCode) |
void |
DepositSwitchCreateRequest.CountryCodeEnum.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
DepositSwitchCreateRequest.CountryCodeEnum enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.