| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static DocumentAuthenticityMatchCode |
DocumentAuthenticityMatchCode.fromValue(String value) |
DocumentAuthenticityMatchCode |
DocumentAnalysis.getAuthenticity()
Get authenticity
|
DocumentAuthenticityMatchCode |
DocumentAuthenticityMatchCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static DocumentAuthenticityMatchCode |
DocumentAuthenticityMatchCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DocumentAuthenticityMatchCode[] |
DocumentAuthenticityMatchCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
DocumentAnalysis |
DocumentAnalysis.authenticity(DocumentAuthenticityMatchCode authenticity) |
void |
DocumentAnalysis.setAuthenticity(DocumentAuthenticityMatchCode authenticity) |
void |
DocumentAuthenticityMatchCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
DocumentAuthenticityMatchCode enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.