| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static DocumentNameMatchCode |
DocumentNameMatchCode.fromValue(String value) |
DocumentNameMatchCode |
PhysicalDocumentExtractedDataAnalysis.getName()
Get name
|
DocumentNameMatchCode |
DocumentNameMatchCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static DocumentNameMatchCode |
DocumentNameMatchCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DocumentNameMatchCode[] |
DocumentNameMatchCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
PhysicalDocumentExtractedDataAnalysis |
PhysicalDocumentExtractedDataAnalysis.name(DocumentNameMatchCode name) |
void |
PhysicalDocumentExtractedDataAnalysis.setName(DocumentNameMatchCode name) |
void |
DocumentNameMatchCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
DocumentNameMatchCode enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.