| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static EntityWatchlistCode |
EntityWatchlistCode.fromValue(String value) |
EntityWatchlistCode |
EntityWatchlistScreeningHit.getListCode()
Get listCode
|
EntityWatchlistCode |
EntityWatchlistCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static EntityWatchlistCode |
EntityWatchlistCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static EntityWatchlistCode[] |
EntityWatchlistCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
Set<EntityWatchlistCode> |
EntityWatchlistProgram.getListsEnabled()
Watchlists enabled for the associated program
|
Set<EntityWatchlistCode> |
WatchlistScreeningEntityProgramGetResponse.getListsEnabled()
Watchlists enabled for the associated program
|
| Modifier and Type | Method and Description |
|---|---|
EntityWatchlistProgram |
EntityWatchlistProgram.addListsEnabledItem(EntityWatchlistCode listsEnabledItem) |
WatchlistScreeningEntityProgramGetResponse |
WatchlistScreeningEntityProgramGetResponse.addListsEnabledItem(EntityWatchlistCode listsEnabledItem) |
EntityWatchlistScreeningHit |
EntityWatchlistScreeningHit.listCode(EntityWatchlistCode listCode) |
void |
EntityWatchlistScreeningHit.setListCode(EntityWatchlistCode listCode) |
void |
EntityWatchlistCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
EntityWatchlistCode enumeration) |
| Modifier and Type | Method and Description |
|---|---|
EntityWatchlistProgram |
EntityWatchlistProgram.listsEnabled(Set<EntityWatchlistCode> listsEnabled) |
WatchlistScreeningEntityProgramGetResponse |
WatchlistScreeningEntityProgramGetResponse.listsEnabled(Set<EntityWatchlistCode> listsEnabled) |
void |
EntityWatchlistProgram.setListsEnabled(Set<EntityWatchlistCode> listsEnabled) |
void |
WatchlistScreeningEntityProgramGetResponse.setListsEnabled(Set<EntityWatchlistCode> listsEnabled) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.