| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
ItemApplicationScopesUpdateResponse |
ItemApplicationScopesUpdateResponse.requestId(String requestId) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<ItemApplicationScopesUpdateResponse> |
PlaidApi.itemApplicationScopesUpdate(ItemApplicationScopesUpdateRequest itemApplicationScopesUpdateRequest)
Update the scopes of access for a particular application
Enable consumers to update product access on selected accounts for an application.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.