| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static LinkDeliveryWebhookCommunicationMethod |
LinkDeliveryWebhookCommunicationMethod.fromValue(String value) |
LinkDeliveryWebhookCommunicationMethod |
LinkDeliveryMetadata.getCommunicationMethod()
Get communicationMethod
|
LinkDeliveryWebhookCommunicationMethod |
LinkDeliveryWebhookCommunicationMethod.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static LinkDeliveryWebhookCommunicationMethod |
LinkDeliveryWebhookCommunicationMethod.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static LinkDeliveryWebhookCommunicationMethod[] |
LinkDeliveryWebhookCommunicationMethod.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
LinkDeliveryMetadata |
LinkDeliveryMetadata.communicationMethod(LinkDeliveryWebhookCommunicationMethod communicationMethod) |
void |
LinkDeliveryMetadata.setCommunicationMethod(LinkDeliveryWebhookCommunicationMethod communicationMethod) |
void |
LinkDeliveryWebhookCommunicationMethod.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
LinkDeliveryWebhookCommunicationMethod enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.