| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static MatchSummaryCode |
MatchSummaryCode.fromValue(String value) |
MatchSummaryCode |
KYCCheckPhoneSummary.getAreaCode()
Get areaCode
|
MatchSummaryCode |
ScreeningHitAnalysis.getDatesOfBirth()
Get datesOfBirth
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getDocuments()
Get documents
|
MatchSummaryCode |
ScreeningHitAnalysis.getDocuments()
Get documents
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getEmailAddresses()
Get emailAddresses
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getLocations()
Get locations
|
MatchSummaryCode |
ScreeningHitAnalysis.getLocations()
Get locations
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getNames()
Get names
|
MatchSummaryCode |
ScreeningHitAnalysis.getNames()
Get names
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getPhoneNumbers()
Get phoneNumbers
|
MatchSummaryCode |
KYCCheckAddressSummary.getSummary()
Get summary
|
MatchSummaryCode |
KYCCheckPhoneSummary.getSummary()
Get summary
|
MatchSummaryCode |
KYCCheckIDNumberSummary.getSummary()
Get summary
|
MatchSummaryCode |
KYCCheckDateOfBirthSummary.getSummary()
Get summary
|
MatchSummaryCode |
MatchSummary.getSummary()
Get summary
|
MatchSummaryCode |
KYCCheckNameSummary.getSummary()
Get summary
|
MatchSummaryCode |
EntityScreeningHitAnalysis.getUrls()
Get urls
|
MatchSummaryCode |
MatchSummaryCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static MatchSummaryCode |
MatchSummaryCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static MatchSummaryCode[] |
MatchSummaryCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
KYCCheckPhoneSummary |
KYCCheckPhoneSummary.areaCode(MatchSummaryCode areaCode) |
ScreeningHitAnalysis |
ScreeningHitAnalysis.datesOfBirth(MatchSummaryCode datesOfBirth) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.documents(MatchSummaryCode documents) |
ScreeningHitAnalysis |
ScreeningHitAnalysis.documents(MatchSummaryCode documents) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.emailAddresses(MatchSummaryCode emailAddresses) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.locations(MatchSummaryCode locations) |
ScreeningHitAnalysis |
ScreeningHitAnalysis.locations(MatchSummaryCode locations) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.names(MatchSummaryCode names) |
ScreeningHitAnalysis |
ScreeningHitAnalysis.names(MatchSummaryCode names) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.phoneNumbers(MatchSummaryCode phoneNumbers) |
void |
KYCCheckPhoneSummary.setAreaCode(MatchSummaryCode areaCode) |
void |
ScreeningHitAnalysis.setDatesOfBirth(MatchSummaryCode datesOfBirth) |
void |
EntityScreeningHitAnalysis.setDocuments(MatchSummaryCode documents) |
void |
ScreeningHitAnalysis.setDocuments(MatchSummaryCode documents) |
void |
EntityScreeningHitAnalysis.setEmailAddresses(MatchSummaryCode emailAddresses) |
void |
EntityScreeningHitAnalysis.setLocations(MatchSummaryCode locations) |
void |
ScreeningHitAnalysis.setLocations(MatchSummaryCode locations) |
void |
EntityScreeningHitAnalysis.setNames(MatchSummaryCode names) |
void |
ScreeningHitAnalysis.setNames(MatchSummaryCode names) |
void |
EntityScreeningHitAnalysis.setPhoneNumbers(MatchSummaryCode phoneNumbers) |
void |
KYCCheckAddressSummary.setSummary(MatchSummaryCode summary) |
void |
KYCCheckPhoneSummary.setSummary(MatchSummaryCode summary) |
void |
KYCCheckIDNumberSummary.setSummary(MatchSummaryCode summary) |
void |
KYCCheckDateOfBirthSummary.setSummary(MatchSummaryCode summary) |
void |
MatchSummary.setSummary(MatchSummaryCode summary) |
void |
KYCCheckNameSummary.setSummary(MatchSummaryCode summary) |
void |
EntityScreeningHitAnalysis.setUrls(MatchSummaryCode urls) |
KYCCheckAddressSummary |
KYCCheckAddressSummary.summary(MatchSummaryCode summary) |
KYCCheckPhoneSummary |
KYCCheckPhoneSummary.summary(MatchSummaryCode summary) |
KYCCheckIDNumberSummary |
KYCCheckIDNumberSummary.summary(MatchSummaryCode summary) |
KYCCheckDateOfBirthSummary |
KYCCheckDateOfBirthSummary.summary(MatchSummaryCode summary) |
MatchSummary |
MatchSummary.summary(MatchSummaryCode summary) |
KYCCheckNameSummary |
KYCCheckNameSummary.summary(MatchSummaryCode summary) |
EntityScreeningHitAnalysis |
EntityScreeningHitAnalysis.urls(MatchSummaryCode urls) |
void |
MatchSummaryCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
MatchSummaryCode enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.