| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
ProcessorTokenCreateResponse |
ProcessorTokenCreateResponse.processorToken(String processorToken) |
ProcessorTokenCreateResponse |
ProcessorTokenCreateResponse.requestId(String requestId) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<ProcessorTokenCreateResponse> |
PlaidApi.processorApexProcessorTokenCreate(ProcessorApexProcessorTokenCreateRequest processorApexProcessorTokenCreateRequest)
Create Apex bank account token
Used to create a token suitable for sending to Apex to enable Plaid-Apex integrations.
|
retrofit2.Call<ProcessorTokenCreateResponse> |
PlaidApi.processorTokenCreate(ProcessorTokenCreateRequest processorTokenCreateRequest)
Create processor token
Used to create a token suitable for sending to one of Plaid's partners to enable integrations.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.