| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static RiskCheckBehaviorBotDetectedLabel |
RiskCheckBehaviorBotDetectedLabel.fromValue(String value) |
RiskCheckBehaviorBotDetectedLabel |
RiskCheckBehavior.getBotDetected()
Get botDetected
|
RiskCheckBehaviorBotDetectedLabel |
RiskCheckBehaviorBotDetectedLabel.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static RiskCheckBehaviorBotDetectedLabel |
RiskCheckBehaviorBotDetectedLabel.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static RiskCheckBehaviorBotDetectedLabel[] |
RiskCheckBehaviorBotDetectedLabel.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
RiskCheckBehavior |
RiskCheckBehavior.botDetected(RiskCheckBehaviorBotDetectedLabel botDetected) |
void |
RiskCheckBehavior.setBotDetected(RiskCheckBehaviorBotDetectedLabel botDetected) |
void |
RiskCheckBehaviorBotDetectedLabel.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
RiskCheckBehaviorBotDetectedLabel enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.