| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static SandboxItemFireWebhookRequest.WebhookCodeEnum |
SandboxItemFireWebhookRequest.WebhookCodeEnum.fromValue(String value) |
SandboxItemFireWebhookRequest.WebhookCodeEnum |
SandboxItemFireWebhookRequest.getWebhookCode()
The webhook codes that can be fired by this test endpoint.
|
SandboxItemFireWebhookRequest.WebhookCodeEnum |
SandboxItemFireWebhookRequest.WebhookCodeEnum.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static SandboxItemFireWebhookRequest.WebhookCodeEnum |
SandboxItemFireWebhookRequest.WebhookCodeEnum.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static SandboxItemFireWebhookRequest.WebhookCodeEnum[] |
SandboxItemFireWebhookRequest.WebhookCodeEnum.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
void |
SandboxItemFireWebhookRequest.setWebhookCode(SandboxItemFireWebhookRequest.WebhookCodeEnum webhookCode) |
SandboxItemFireWebhookRequest |
SandboxItemFireWebhookRequest.webhookCode(SandboxItemFireWebhookRequest.WebhookCodeEnum webhookCode) |
void |
SandboxItemFireWebhookRequest.WebhookCodeEnum.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
SandboxItemFireWebhookRequest.WebhookCodeEnum enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.