| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static TransactionCode |
TransactionCode.fromValue(String value) |
TransactionCode |
TransactionAllOf.getTransactionCode()
Get transactionCode
|
TransactionCode |
Transaction.getTransactionCode()
Get transactionCode
|
TransactionCode |
TransactionCode.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static TransactionCode |
TransactionCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static TransactionCode[] |
TransactionCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
void |
TransactionAllOf.setTransactionCode(TransactionCode transactionCode) |
void |
Transaction.setTransactionCode(TransactionCode transactionCode) |
TransactionAllOf |
TransactionAllOf.transactionCode(TransactionCode transactionCode) |
Transaction |
Transaction.transactionCode(TransactionCode transactionCode) |
void |
TransactionCode.Adapter.write(com.google.gson.stream.JsonWriter jsonWriter,
TransactionCode enumeration) |
Copyright © 2017–2023 Plaid Inc.. All rights reserved.