| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
TransferIntentCreateResponse |
TransferIntentCreateResponse.requestId(String requestId) |
TransferIntentCreateResponse |
TransferIntentCreateResponse.transferIntent(TransferIntentCreate transferIntent) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<TransferIntentCreateResponse> |
PlaidApi.transferIntentCreate(TransferIntentCreateRequest transferIntentCreateRequest)
Create a transfer intent object to invoke the Transfer UI
Use the `/transfer/intent/create` endpoint to generate a transfer intent object and invoke the Transfer UI.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.