| Package | Description |
|---|---|
| com.plaid.client.model | |
| com.plaid.client.request |
| Modifier and Type | Method and Description |
|---|---|
WatchlistScreeningEntityCreateRequest |
WatchlistScreeningEntityCreateRequest.clientId(String clientId) |
WatchlistScreeningEntityCreateRequest |
WatchlistScreeningEntityCreateRequest.clientUserId(String clientUserId) |
WatchlistScreeningEntityCreateRequest |
WatchlistScreeningEntityCreateRequest.searchTerms(EntityWatchlistSearchTerms searchTerms) |
WatchlistScreeningEntityCreateRequest |
WatchlistScreeningEntityCreateRequest.secret(String secret) |
| Modifier and Type | Method and Description |
|---|---|
retrofit2.Call<WatchlistScreeningEntityCreateResponse> |
PlaidApi.watchlistScreeningEntityCreate(WatchlistScreeningEntityCreateRequest watchlistScreeningEntityCreateRequest)
Create a watchlist screening for an entity
Create a new entity watchlist screening to check your customer against watchlists defined in the associated entity watchlist program.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.