| Package | Description |
|---|---|
| com.plaid.client.model |
| Modifier and Type | Method and Description |
|---|---|
static WebhookEnvironmentValues |
WebhookEnvironmentValues.fromValue(String value) |
WebhookEnvironmentValues |
CraBankIncomeCompleteWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProductPermissionsRequiredAuthWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
PartnerEndCustomerOAuthStatusUpdatedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
PendingExpirationWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
HistoricalUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
TransferEventsUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorHistoricalUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
UserPermissionRevokedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
AssetsErrorWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
PaymentStatusUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IdentityVerificationStatusUpdatedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
InvestmentsDefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ItemErrorWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
InvestmentsHistoricalUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
RecurringNewTransferWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ItemProductReadyWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BankIncomeRefreshUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
VerificationExpiredWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
SyncUpdatesAvailableWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IncomeVerificationStatusWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IncomeVerificationRiskSignalsStatusWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProductPermissionsRequiredIdentityWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
DepositSwitchStateUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
RecurringCancelledWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BankIncomeRefreshCompleteWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
FallbackAuthMicrodepositAutoVerifiedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ItemLoginRepairedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
InstitutionStatusAlertWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
HoldingsDefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorTransactionsRemovedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
RecurringTransactionsUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorTokenWebhookUpdate.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
RecurringTransferSkippedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
WalletTransactionStatusUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
AssetsProductReadyWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IdentityDefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
LiabilitiesDefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
EntityScreeningStatusUpdatedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BankIncomeCompleteWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IdentityVerificationRetriedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BankTransfersEventsUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BaseReportsProductReadyWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
AutomaticallyVerifiedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ScreeningStatusUpdatedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorDefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
IdentityVerificationStepUpdatedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorSyncUpdatesAvailableWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
TransactionsRemovedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorInitialUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
NewAccountsAvailableWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BaseReportsErrorWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
WebhookUpdateAcknowledgedWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
BankTransfersEventsUpdateWebhookForAuth.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
InitialUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
DefaultUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
ProcessorRecurringTransactionsUpdateWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
FallbackAuthMicrodepositVerificationExpiredWebhook.getEnvironment()
Get environment
|
WebhookEnvironmentValues |
WebhookEnvironmentValues.Adapter.read(com.google.gson.stream.JsonReader jsonReader) |
static WebhookEnvironmentValues |
WebhookEnvironmentValues.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static WebhookEnvironmentValues[] |
WebhookEnvironmentValues.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2017–2023 Plaid Inc.. All rights reserved.