@Generated(value="org.openapitools.codegen.languages.JavaClientCodegen", date="2023-08-10T22:39:54.038561Z[Etc/UTC]") public class SimulatedTransferSweep extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
SERIALIZED_NAME_AMOUNT |
static String |
SERIALIZED_NAME_CREATED |
static String |
SERIALIZED_NAME_FUNDING_ACCOUNT_ID |
static String |
SERIALIZED_NAME_ID |
static String |
SERIALIZED_NAME_ISO_CURRENCY_CODE |
static String |
SERIALIZED_NAME_SETTLED |
static String |
SERIALIZED_NAME_STATUS |
| Constructor and Description |
|---|
SimulatedTransferSweep() |
| Modifier and Type | Method and Description |
|---|---|
SimulatedTransferSweep |
amount(String amount) |
SimulatedTransferSweep |
created(OffsetDateTime created) |
boolean |
equals(Object o) |
SimulatedTransferSweep |
fundingAccountId(String fundingAccountId) |
String |
getAmount()
Signed decimal amount of the sweep as it appears on your sweep account ledger (e.g.
|
OffsetDateTime |
getCreated()
The datetime when the sweep occurred, in RFC 3339 format.
|
String |
getFundingAccountId()
The id of the funding account to use, available in the Plaid Dashboard.
|
String |
getId()
Identifier of the sweep.
|
String |
getIsoCurrencyCode()
The currency of the sweep, e.g.
|
LocalDate |
getSettled()
The date when the sweep settled, in the YYYY-MM-DD format.
|
SweepStatus |
getStatus()
Get status
|
int |
hashCode() |
SimulatedTransferSweep |
id(String id) |
SimulatedTransferSweep |
isoCurrencyCode(String isoCurrencyCode) |
void |
setAmount(String amount) |
void |
setCreated(OffsetDateTime created) |
void |
setFundingAccountId(String fundingAccountId) |
void |
setId(String id) |
void |
setIsoCurrencyCode(String isoCurrencyCode) |
void |
setSettled(LocalDate settled) |
void |
setStatus(SweepStatus status) |
SimulatedTransferSweep |
settled(LocalDate settled) |
SimulatedTransferSweep |
status(SweepStatus status) |
String |
toString() |
public static final String SERIALIZED_NAME_ID
public static final String SERIALIZED_NAME_FUNDING_ACCOUNT_ID
public static final String SERIALIZED_NAME_CREATED
public static final String SERIALIZED_NAME_AMOUNT
public static final String SERIALIZED_NAME_ISO_CURRENCY_CODE
public static final String SERIALIZED_NAME_SETTLED
public static final String SERIALIZED_NAME_STATUS
public SimulatedTransferSweep id(String id)
public String getId()
public void setId(String id)
public SimulatedTransferSweep fundingAccountId(String fundingAccountId)
public String getFundingAccountId()
public void setFundingAccountId(String fundingAccountId)
public SimulatedTransferSweep created(OffsetDateTime created)
public OffsetDateTime getCreated()
public void setCreated(OffsetDateTime created)
public SimulatedTransferSweep amount(String amount)
public String getAmount()
public void setAmount(String amount)
public SimulatedTransferSweep isoCurrencyCode(String isoCurrencyCode)
public String getIsoCurrencyCode()
public void setIsoCurrencyCode(String isoCurrencyCode)
public SimulatedTransferSweep settled(LocalDate settled)
@Nullable public LocalDate getSettled()
public void setSettled(LocalDate settled)
public SimulatedTransferSweep status(SweepStatus status)
@Nullable public SweepStatus getStatus()
public void setStatus(SweepStatus status)
Copyright © 2017–2023 Plaid Inc.. All rights reserved.